@@ -10,7 +10,9 @@
 #define __Mothur__testoptimatrix__
 
 #include "optimatrix.h"
-#include "../../googletest/include/gtest/gtest.h"
+#include "gtest/gtest.h"
+#include "gmock/gmock.h"
+
 
 class TestOptiMatrix : public OptiMatrix {
     
@@ -19,14 +21,15 @@ public:
     TestOptiMatrix();
     ~TestOptiMatrix();
     
-    using OptiMatrix::getCloseSeqs;
-    using OptiMatrix::readBlast;
-    using OptiMatrix::readBlastNames;
+    using OptiData::getCloseSeqs;
     using OptiMatrix::readPhylip;
     using OptiMatrix::readColumn;
+    using OptiData::print;
+    using OptiData::getNumClose;
     
-    string columnFile, phylipFile, blastFile;
+    string columnFile, phylipFile;
     vector<string> filenames;
+
     
 };
 
