@@ -28,7 +28,7 @@ public:
 	virtual EstOutput getValues(SAbundVector*) = 0;	
 	virtual EstOutput getValues(vector<SharedRAbundVector*>) = 0;
     //optional calc that returns the otus labels of shared otus
-    virtual EstOutput getValues(vector<SharedRAbundVector*> sv , vector<string>&) { data = getValues(sv); return data; }
+    virtual EstOutput getValues(vector<SharedRAbundVector*> sv, vector<string>&, vector<string>) { data = getValues(sv); return data; }
 	virtual void print(ostream& f)	{ f.setf(ios::fixed, ios::floatfield); f.setf(ios::showpoint);
 									  f << data[0]; for(int i=1;i<data.size();i++){	f << '\t' << data[i];	}}
     
@@ -41,6 +41,7 @@ public:
 	void citation() { m->mothurOut(getCitation()); m->mothurOutEndLine(); }
     
 protected:
+    Utils util;
 	MothurOut* m;
 	EstOutput data;
 	string name;
@@ -51,7 +52,10 @@ protected:
 };
 
 /**************************************************************************************************/
-
+//True Negative - far, cluster apart
+//True Positive - close, cluster together
+//False Negative - close, cluster apart
+//False Positve - far, cluster together
 
 class ClusterMetric {
     
@@ -68,6 +72,7 @@ public:
     
 protected:
     MothurOut* m;
+    Utils util;
     string name;
     
     
@@ -87,6 +92,7 @@ public:
 protected:
     double dist;
     MothurOut* m;
+    Utils util;
 };
 
 /**************************************************************************************************/
