@@ -21,14 +21,14 @@ EstOutput MemChi2::getValues(vector<SharedRAbundVector*> shared) {
 		
 		//for each otu
 		for (int i = 0; i < shared[0]->getNumBins(); i++) {
-			if (shared[0]->getAbundance(i) != 0) { nonZeroA++; }
-			if (shared[1]->getAbundance(i) != 0) { nonZeroB++; }
+			if (shared[0]->get(i) != 0) { nonZeroA++; }
+			if (shared[1]->get(i) != 0) { nonZeroB++; }
 		}
 		
 		double sum = 0.0;
 		for (int i = 0; i < shared[0]->getNumBins(); i++) {
-			int A = shared[0]->getAbundance(i);
-			int B = shared[1]->getAbundance(i);
+			int A = shared[0]->get(i);
+			int B = shared[1]->get(i);
 			
 			if (A > 0) { A = 1; }
 			if (B > 0) { B = 1; }
@@ -38,7 +38,7 @@ EstOutput MemChi2::getValues(vector<SharedRAbundVector*> shared) {
 
 			int incidence = 0;
 			for(int j=0;j<shared.size();j++){
-				if(shared[j]->getAbundance(i) != 0){	incidence++;	}
+				if(shared[j]->get(i) != 0){	incidence++;	}
 			}
 			
 			if(incidence != 0){
