@@ -101,7 +101,7 @@ int getRoot(Tree* t, bool includeRoot, int v, vector<string> grouping, map< vect
             
             //while you aren't at root
             while(t->tree[index].getParent() != -1){
-                //cout << index << endl;
+                
                 if (m->getControl_pressed()) {  return 0; }
                 
                 //am I the root for this grouping? if so I want to stop "early"
@@ -135,7 +135,7 @@ int getRoot(Tree* t, bool includeRoot, int v, vector<string> grouping, map< vect
             while(t->tree[index].getParent() != -1){
                 int parent = t->tree[index].getParent();
                 rootForGrouping[grouping].insert(parent);
-                //cout << parent << " in root" << endl;
+                
                 index = parent;
             }
         }
@@ -194,17 +194,17 @@ void driverUnweighted(unweightedData* params) {
                     
                     //unique calc
                     if (pcountSize == 0) { }
-                    else if ((params->t->tree[i].getBranchLength() != -1) && (pcountSize == 1) && (rootForGrouping[params->namesOfGroupCombos[h]].count(i) == 0)) { //you have a unique branch length and you are not the root
+                    else if (!params->util.isEqual(params->t->tree[i].getBranchLength(), -1) && (pcountSize == 1) && (rootForGrouping[params->namesOfGroupCombos[h]].count(i) == 0)) { //you have a unique branch length and you are not the root
                         UniqueBL += abs(params->t->tree[i].getBranchLength());
                     }
                     
                     //total calc
                     if (pcountSize == 0) { }
-                    else if ((params->t->tree[i].getBranchLength() != -1) && (pcountSize != 0) && (rootForGrouping[params->namesOfGroupCombos[h]].count(i) == 0)) { //you have a branch length and you are not the root
+                    else if (!params->util.isEqual(params->t->tree[i].getBranchLength(), -1) && (pcountSize != 0) && (rootForGrouping[params->namesOfGroupCombos[h]].count(i) == 0)) { //you have a branch length and you are not the root
                         totalBL += abs(params->t->tree[i].getBranchLength());
                     }
                 }
-                //cout << UniqueBL << '\t' << totalBL << endl;
+                
                 UW = (UniqueBL / totalBL);
                 
                 if (isnan(UW) || isinf(UW)) { UW = 0; }
@@ -353,13 +353,13 @@ void driverRandomCalcs(unweightedData* params) {
                     
                     //unique calc
                     if (pcountSize == 0) { }
-                    else if ((copyTree->tree[i].getBranchLength() != -1) && (pcountSize == 1) && (rootForGrouping[params->namesOfGroupCombos[h]].count(i) == 0)) { //you have a unique branch length and you are not the root
+                    else if (!params->util.isEqual(copyTree->tree[i].getBranchLength(), -1) && (pcountSize == 1) && (rootForGrouping[params->namesOfGroupCombos[h]].count(i) == 0)) { //you have a unique branch length and you are not the root
                         UniqueBL += abs(copyTree->tree[i].getBranchLength());
                     }
                     
                     //total calc
                     if (pcountSize == 0) { }
-                    else if ((copyTree->tree[i].getBranchLength() != -1) && (pcountSize != 0) && (rootForGrouping[params->namesOfGroupCombos[h]].count(i) == 0)) { //you have a branch length and you are not the root
+                    else if (!params->util.isEqual(copyTree->tree[i].getBranchLength(), -1) && (pcountSize != 0) && (rootForGrouping[params->namesOfGroupCombos[h]].count(i) == 0)) { //you have a branch length and you are not the root
                         totalBL += abs(copyTree->tree[i].getBranchLength()); 
                     }
                     
