@@ -26,10 +26,11 @@ Ccode::Ccode(string filename, string temp, bool f, string mask, int win, int num
 	distCalc = new eachGapDist();
 	decalc = new DeCalculator();
 	
-	mapInfo = outputDir + m->getRootName(m->getSimpleName(fastafile)) + "mapinfo";
+     Utils util;
+	mapInfo = outputDir + util.getRootName(util.getSimpleName(fastafile)) + "mapinfo";
     
      ofstream out2;
-     m->openOutputFile(mapInfo, out2);
+     util.openOutputFile(mapInfo, out2);
      
      out2 << "Place in masked, filtered and trimmed sequence\tPlace in original alignment" << endl;
      out2.close();
@@ -50,7 +51,7 @@ Sequence Ccode::print(ostream& out, ostream& outAcc) {
 	try {
 		
 		ofstream out2;
-		m->openOutputFileAppend(mapInfo, out2);
+		Utils util; util.openOutputFileAppend(mapInfo, out2);
 		
 		out2 << querySeq->getName() << endl;
 		for (it = spotMap.begin(); it!= spotMap.end(); it++) {
@@ -165,7 +166,7 @@ int Ccode::getChimeras(Sequence* query) {
 		//find closest matches to query
 		closest = findClosest(query, numWanted);
 		
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 		
 		//initialize spotMap
 		for (int i = 0; i < query->getAligned().length(); i++) {	spotMap[i] = i;		}
@@ -190,7 +191,7 @@ int Ccode::getChimeras(Sequence* query) {
 			createFilter(temp, 0.5);
 		
 			for (int i = 0; i < temp.size(); i++) { 
-				if (m->control_pressed) {  return 0;  }
+				if (m->getControl_pressed()) {  return 0;  }
 				runFilter(temp[i]);  
 			}
 			
@@ -210,32 +211,32 @@ int Ccode::getChimeras(Sequence* query) {
 
 		//trim sequences - this follows ccodes remove_extra_gaps 
 		trimSequences(query);
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 		
 		//windows are equivalent to words - ccode paper recommends windows are between 5% and 20% on alignment length().  
 		//Our default will be 10% and we will warn if user tries to use a window above or below these recommendations
 		windows = findWindows();  
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 
 		//remove sequences that are more than 20% different and less than 0.5% different - may want to allow user to specify this later 
 		removeBadReferenceSeqs(closest);
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 		
 		//find the averages for each querys references
 		getAverageRef(closest);  //fills sumRef, averageRef, sumSquaredRef and refCombo.
 		getAverageQuery(closest, query);  //fills sumQuery, averageQuery, sumSquaredQuery.
-		if (m->control_pressed) {  return 0;  }			
+		if (m->getControl_pressed()) {  return 0;  }			
 		
 		//find the averages for each querys references 
 		findVarianceRef();  //fills varRef and sdRef also sets minimum error rate to 0.001 to avoid divide by 0.
-		if (m->control_pressed) {  return 0;  }	
+		if (m->getControl_pressed()) {  return 0;  }	
 			
 		//find the averages for the query 
 		findVarianceQuery();  //fills varQuery and sdQuery also sets minimum error rate to 0.001 to avoid divide by 0.
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 					
 		determineChimeras();  //fills anova, isChimericConfidence, isChimericTStudent and isChimericANOVA. 
-		if (m->control_pressed) {  return 0;  }
+		if (m->getControl_pressed()) {  return 0;  }
 		
 		return 0;
 	}
@@ -526,9 +527,8 @@ vector<SeqDist>  Ccode::findClosest(Sequence* q, int numWanted) {
 			Sequence ref = *(templateSeqs[i]); 
 					
 			//find overall dist
-			distCalc->calcDist(query, ref);
-			float dist = distCalc->getDist();	
-				
+			double dist = distCalc->calcDist(query, ref);
+							
 			//save distance
 			SeqDist temp;
 			temp.seq = new Sequence(templateSeqs[i]->getName(), templateSeqs[i]->getAligned());
