@@ -13,6 +13,7 @@
 
 #include "mothur.h"
 #include "mothurout.h"
+#include "utils.hpp"
 
 //reads in taxonomy file and makes all the taxonomies the same length 
 //by appending the last taxon to a given taxonomy as many times as needed to 
@@ -40,6 +41,7 @@ private:
 	void extendTaxonomy(string, string&, int);  //name, taxonomy, desired level
 	void truncateTaxonomy(string, string&, int);  //name, taxonomy, desired level
 	MothurOut* m;
+    Utils util;
 	
 };
 
