@@ -154,6 +154,7 @@
 #include "mergecountcommand.hpp"
 #include "clusterfitcommand.hpp"
 #include "mergeotuscommand.hpp"
+#include "diversityestimatorcommand.hpp"
 
 
 /*******************************************************/
@@ -173,10 +174,6 @@ CommandFactory::CommandFactory(){
 	m = MothurOut::getInstance();
     current = CurrentFile::getInstance();
 
-	command = new NoCommand(s);
-	shellcommand = new NoCommand(s);
-	pipecommand = new NoCommand(s);
-
 	current->setOutputDir(""); current->setInputDir("");
 	append = false;
 
@@ -329,6 +326,7 @@ CommandFactory::CommandFactory(){
     commands["merge.count"]         = "merge.count";
     commands["cluster.fit"]         = "cluster.fit";
     commands["merge.otus"]         = "merge.otus";
+    commands["estimator.single"]    = "estimator.single";
 
 
 }
@@ -336,9 +334,6 @@ CommandFactory::CommandFactory(){
 /***********************************************************/
 CommandFactory::~CommandFactory(){
 	_uniqueInstance = 0;
-	delete command;
-	delete shellcommand;
-	delete pipecommand;
 }
 /***********************************************************/
 
@@ -419,7 +414,7 @@ int CommandFactory::checkForRedirects(string optionString) {
 Command* CommandFactory::getCommand(string commandName, string optionString){
 	try {
 
-		delete command;   //delete the old command
+        Command* command = NULL;
         
         if (commandName != "help") {
             checkForRedirects(optionString);
@@ -581,6 +576,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
         else if(commandName == "rename.file")           {	command = new RenameFileCommand(optionString);              }
         else if(commandName == "cluster.fit")           {	command = new ClusterFitCommand(optionString);              }
         else if(commandName == "merge.otus")            {	command = new MergeOTUsCommand(optionString);               }
+        else if(commandName == "estimator.single")      {	command = new EstimatorSingleCommand(optionString);         }
 		else											{	command = new NoCommand(optionString);						}
 
 		return command;
@@ -596,7 +592,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 //This function calls the appropriate command fucntions based on user input.
 Command* CommandFactory::getCommand(string commandName, string optionString, string mode){
 	try {
-		delete pipecommand;   //delete the old command
+		Command* pipecommand = NULL;   //delete the old command
         
         if (commandName != "help") {
             checkForRedirects(optionString);
@@ -757,6 +753,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
         else if(commandName == "rename.file")           {	pipecommand = new RenameFileCommand(optionString);              }
         else if(commandName == "cluster.fit")           {	pipecommand = new ClusterFitCommand(optionString);              }
         else if(commandName == "merge.otus")            {	pipecommand = new MergeOTUsCommand(optionString);               }
+        else if(commandName == "estimator.single")      {	pipecommand = new EstimatorSingleCommand(optionString);         }
 		else											{	pipecommand = new NoCommand(optionString);						}
         
 
@@ -773,7 +770,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
 //This function calls the appropriate command fucntions based on user input, this is used by the pipeline command to check a users piepline for errors before running
 Command* CommandFactory::getCommand(string commandName){
 	try {
-		delete shellcommand;   //delete the old command
+		Command* shellcommand = NULL;   //delete the old command
 
 		if(commandName == "cluster")				{	shellcommand = new ClusterCommand();				}
 		else if(commandName == "unique.seqs")			{	shellcommand = new DeconvoluteCommand();			}
@@ -919,6 +916,7 @@ Command* CommandFactory::getCommand(string commandName){
         else if(commandName == "rename.file")           {	shellcommand = new RenameFileCommand();             }
         else if(commandName == "cluster.fit")           {	shellcommand = new ClusterFitCommand();             }
         else if(commandName == "merge.otus")            {	shellcommand = new MergeOTUsCommand();              }
+        else if(commandName == "estimator.single")      {	shellcommand = new EstimatorSingleCommand();        }
 		else											{	shellcommand = new NoCommand();						}
 
 		return shellcommand;
