@@ -99,7 +99,7 @@ AnosimCommand::AnosimCommand(string option) {
 			//check to make sure all parameters are valid for command
 			map<string,string>::iterator it;
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -136,8 +136,8 @@ AnosimCommand::AnosimCommand(string option) {
 			else if (phylipFileName == "not found") { 
 				//if there is a current phylip file, use it
 				phylipFileName = current->getPhylipFile(); 
-				if (phylipFileName != "") { m->mothurOut("Using " + phylipFileName + " as input file for the phylip parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current phylip file and the phylip parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (phylipFileName != "") { m->mothurOut("Using " + phylipFileName + " as input file for the phylip parameter.\n"); }
+				else { 	m->mothurOut("You have no current phylip file and the phylip parameter is required.\n"); abort = true; }
 				
 			}else { current->setPhylipFile(phylipFileName); }	
 			
@@ -147,8 +147,8 @@ AnosimCommand::AnosimCommand(string option) {
 			else if (designFileName == "not found") {
 				//if there is a current design file, use it
 				designFileName = current->getDesignFile(); 
-				if (designFileName != "") { m->mothurOut("Using " + designFileName + " as input file for the design parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current design file and the design parameter is required."); m->mothurOutEndLine(); abort = true; }								
+				if (designFileName != "") { m->mothurOut("Using " + designFileName + " as input file for the design parameter.\n"); }
+				else { 	m->mothurOut("You have no current design file and the design parameter is required.\n");  abort = true; }
 			}else { current->setDesignFile(designFileName); }	
 			
 			string temp = validParameter.valid(parameters, "iters");
@@ -222,7 +222,7 @@ int AnosimCommand::execute(){
 			for(map<string, vector<int> >::iterator itA=origGroupSampleMap.begin();itA!=origGroupSampleMap.end();itA++){
 				map<string, vector<int> >::iterator itB = itA;
 				itB++;
-				for(itB;itB!=origGroupSampleMap.end();itB++){
+				for(;itB!=origGroupSampleMap.end();itB++){
 					
 					map<string, vector<int> > subGroupSampleMap;
 					
@@ -356,7 +356,7 @@ double AnosimCommand::calcR(vector<vector<double> > rankMatrix, map<string, vect
 				int A = itA->second[i];
 				map<string, vector<int> >::iterator itB = itA;
 				itB++;
-				for(itB;itB!=groupSampleMap.end();itB++){
+				for(;itB!=groupSampleMap.end();itB++){
 					for(int j=0;j<itB->second.size();j++){
 						int B = itB->second[j];
 						if(A>B)	{	between += rankMatrix[A][B];	}
