@@ -15,22 +15,17 @@
 //**********************************************************************************************************************
 vector<string> ClassifyRFSharedCommand::setParameters(){	
 	try {
-		//CommandParameter pprocessors("processors", "Number", "", "1", "", "", "",false,false); parameters.push_back(pprocessors);        
         CommandParameter pshared("shared", "InputTypes", "", "", "none", "none", "none","summary",false,true,true); parameters.push_back(pshared);		
         CommandParameter pdesign("design", "InputTypes", "", "", "none", "none", "none","",false,true,true); parameters.push_back(pdesign);	
         CommandParameter potupersplit("otupersplit", "Multiple", "log2-squareroot", "log2", "", "", "","",false,false); parameters.push_back(potupersplit);
         CommandParameter psplitcriteria("splitcriteria", "Multiple", "gainratio-infogain", "gainratio", "", "", "","",false,false); parameters.push_back(psplitcriteria);
 		CommandParameter pnumtrees("numtrees", "Number", "", "100", "", "", "","",false,false); parameters.push_back(pnumtrees);
-        //CommandParameter psets("sets", "String", "", "", "", "", "","",false,false); parameters.push_back(psets);
-            // parameters related to pruning
         CommandParameter pdopruning("prune", "Boolean", "", "T", "", "", "", "", false, false); parameters.push_back(pdopruning);
         CommandParameter ppruneaggrns("pruneaggressiveness", "Number", "", "0.9", "", "", "", "", false, false); parameters.push_back(ppruneaggrns);
         CommandParameter pdiscardhetrees("discarderrortrees", "Boolean", "", "T", "", "", "", "", false, false); parameters.push_back(pdiscardhetrees);
         CommandParameter phetdiscardthreshold("errorthreshold", "Number", "", "0.4", "", "", "", "", false, false); parameters.push_back(phetdiscardthreshold);
         CommandParameter psdthreshold("stdthreshold", "Number", "", "0.0", "", "", "", "", false, false); parameters.push_back(psdthreshold);
-            // pruning params end
-
-        CommandParameter pgroups("groups", "String", "", "", "", "", "","",false,false); parameters.push_back(pgroups);
+         CommandParameter pgroups("groups", "String", "", "", "", "", "","",false,false); parameters.push_back(pgroups);
 		CommandParameter plabel("label", "String", "", "", "", "", "","",false,false); parameters.push_back(plabel);
   		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
@@ -52,7 +47,6 @@ string ClassifyRFSharedCommand::getHelpString(){
 		helpString += "The classify.rf command allows you to ....\n";
 		helpString += "The classify.rf command parameters are: shared, design, label, groups, otupersplit.\n";
         helpString += "The label parameter is used to analyze specific labels in your input.\n";
-        //helpString += "The sets parameter allows you to specify which of the sets in your designfile you would like to analyze. The set names are separated by dashes. THe default is all sets in the designfile.\n";
 		helpString += "The groups parameter allows you to specify which of the groups in your designfile you would like analyzed.\n";
 		helpString += "The classify.rf should be in the following format: \n";
 		helpString += "classify.rf(shared=yourSharedFile, design=yourDesignFile)\n";
@@ -97,7 +91,7 @@ ClassifyRFSharedCommand::ClassifyRFSharedCommand() {
 ClassifyRFSharedCommand::ClassifyRFSharedCommand(string option) {
   try {
     abort = false; calledHelp = false;
-    allLines = 1;
+    allLines = true;
       
       //allow user to run help
     if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -221,8 +215,8 @@ ClassifyRFSharedCommand::ClassifyRFSharedCommand(string option) {
       string label = validParameter.valid(parameters, "label");
       if (label == "not found") { label = ""; }
       else {
-        if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-        else { allLines = 1;  }
+        if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+        else { allLines = true;  }
       }
     }
     
