@@ -43,6 +43,7 @@ public:
 	string getCommandName()			{ return "classify.seqs";		}
 	string getCommandCategory()		{ return "Phylotype Analysis";	}
 	
+    string getCommonQuestions();
 	string getHelpString();	
     string getOutputPattern(string);	
 	string getCitation() { return "Wang Q, Garrity GM, Tiedje JM, Cole JR (2007). Naive Bayesian classifier for rapid assignment of rRNA sequences into the new bacterial taxonomy. Appl Environ Microbiol 73: 5261-7. [ for Bayesian classifier ] \nAltschul SF, Madden TL, Schaffer AA, Zhang J, Zhang Z, Miller W, Lipman DJ (1997). Gapped BLAST and PSI-BLAST: a new generation of protein database search programs. Nucleic Acids Res 25: 3389-402. [ for BLAST ] \nDeSantis TZ, Hugenholtz P, Larsen N, Rojas M, Brodie EL, Keller K, Huber T, Dalevi D, Hu P, Andersen GL (2006). Greengenes, a chimera-checked 16S rRNA gene database and workbench compatible with ARB. Appl Environ Microbiol 72: 5069-72. [ for kmer ] \nhttp://www.mothur.org/wiki/Classify.seqs"; }
@@ -54,20 +55,11 @@ public:
 	
 	
 private:
-
-	vector<int> processIDS;   //processid
-	vector<linePair*> lines;
-	vector<string> fastaFileNames;
-	vector<string> namefileNames;
-    vector<string> countfileNames;
-	vector<string> groupfileNames;
 	vector<string> outputNames;
-	map<string, vector<string> > nameMap;
-	map<string,  vector<string> >::iterator itNames;
 	
 	Classify* classify;
 	
-	string fastaFileName, templateFileName, countfile, distanceFileName, namefile, search, method, taxonomyFileName, outputDir, groupfile, output;
+	string fastafile, templateFileName, countfile, distanceFileName, namefile, search, method, taxonomyFileName, outputDir, groupfile, output;
 	int processors, kmerSize, numWanted, cutoff, iters, printlevel;
 	float match, misMatch, gapOpen, gapExtend;
 	bool abort, probs, save, flip, hasName, hasCount, writeShortcuts, relabund;
