@@ -166,7 +166,7 @@ CollectCommand::CollectCommand(){
 CollectCommand::CollectCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
 		
 		//allow user to run help
 		if(option == "help") { help(); calledHelp = true; abort = true; }
@@ -307,8 +307,8 @@ CollectCommand::CollectCommand(string option)  {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 			
 			//NOTE: if you add new calc options, don't forget to add them to the parameter initialize in setParameters or the gui won't be able to use them
