@@ -93,7 +93,7 @@ ConsensusSeqsCommand::ConsensusSeqsCommand(){
 ConsensusSeqsCommand::ConsensusSeqsCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -190,8 +190,8 @@ ConsensusSeqsCommand::ConsensusSeqsCommand(string option)  {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 			
 			string temp = validParameter.valid(parameters, "cutoff");  if (temp == "not found") { temp = "100"; }
