@@ -83,7 +83,7 @@ CooccurrenceCommand::CooccurrenceCommand(){
 CooccurrenceCommand::CooccurrenceCommand(string option) {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
 				
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -126,8 +126,8 @@ CooccurrenceCommand::CooccurrenceCommand(string option) {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 			
 			//get shared file
