@@ -99,7 +99,7 @@ FilterSharedCommand::FilterSharedCommand(){
 FilterSharedCommand::FilterSharedCommand(string option) {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -162,8 +162,8 @@ FilterSharedCommand::FilterSharedCommand(string option) {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 			
 			groups = validParameter.valid(parameters, "groups");			
@@ -384,7 +384,8 @@ int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
         
         bool filteredSomething = false;
         int numRemoved = 0;
-        for (int i = 0; i < sharedLookup->getNumBins();) {
+        vector<int> binsToRemove;
+        for (int i = 0; i < sharedLookup->getNumBins(); i++) {
             
             if (m->getControl_pressed()) { return 0; }
             
@@ -442,9 +443,8 @@ int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
             }
             
             //did this OTU pass the filter criteria
-            if (okay) {
-                ++i;
-            }else { //if not, do we want to save the counts
+            if (!okay) {
+                
                 filteredSomething = true;
                 if (makeRare) {
                     for (int j = 0; j < numGroups; j++) {
@@ -452,12 +452,14 @@ int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
                     }
                 }
                 if (m->getDebug()) { m->mothurOut("[DEBUG]: removing OTU " + sharedLookup->getOTUName(i) + "\n"); }
-                sharedLookup->removeOTU(i);
+                binsToRemove.push_back(i);
                 numRemoved++;
             }
             
         }
         
+        sharedLookup->removeOTUs(binsToRemove, true);
+        
         //if we are saving the counts add a "rare" OTU if anything was filtered
         if (makeRare) { if (filteredSomething) { sharedLookup->push_back(rareCounts, "OTURare1"); } }
         
