@@ -99,7 +99,7 @@ GetSharedOTUCommand::GetSharedOTUCommand(string option)  {
 	
 		abort = false; calledHelp = false;   userGroups = "";
 		unique = true;
-		allLines = 1;
+		allLines = true;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -244,8 +244,8 @@ GetSharedOTUCommand::GetSharedOTUCommand(string option)  {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 			
 			output = validParameter.valid(parameters, "output");
