@@ -106,7 +106,7 @@ HeatMapSimCommand::HeatMapSimCommand(){
 HeatMapSimCommand::HeatMapSimCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
 			
 		//allow user to run help
 		if(option == "help") {  help(); abort = true; calledHelp = true; }
@@ -252,8 +252,8 @@ HeatMapSimCommand::HeatMapSimCommand(string option)  {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 				
 			calc = validParameter.valid(parameters, "calc");
