@@ -108,7 +108,7 @@ IndicatorCommand::IndicatorCommand(string option)  {
 			
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			vector<string> tempOutNames;
@@ -284,7 +284,7 @@ int IndicatorCommand::execute(){
             }
             ct.createTable(nameMap, groupMap, gps);
 			
-			if ((designfile != "") && (Treenames.size() != namesSeqs.size())) { cout << namesSeqs.size() << '\t' << Treenames.size() << endl; m->mothurOut("[ERROR]: You design file does not match your tree, aborting.\n"); mismatch = true; }
+			if ((designfile != "") && (Treenames.size() != namesSeqs.size())) {  m->mothurOut("[ERROR]: You design file does not match your tree, aborting.\n"); mismatch = true; }
 					
 			if (mismatch) { //cleanup and exit
 				if (designfile != "") { delete designMap; }  return 0;
@@ -355,7 +355,7 @@ vector<float> getValues(vector< vector<SharedRAbundFloatVector*> >& groupings, v
             groupingsGroups.push_back(tempGrouping);
         }
         
-        
+        Utils util;
         //for each otu
         for (int i = 0; i < groupings[0][0]->getNumBins(); i++) {
             
@@ -376,10 +376,11 @@ vector<float> getValues(vector< vector<SharedRAbundFloatVector*> >& groupings, v
                     
                     if (it == groupingsMap.end()) { //this one didnt get moved, or initial calc
                         totalAbund += groupings[j][k]->get(i);
-                        if (groupings[j][k]->get(i) != 0.0) { numNotZero++; }
+                        if (!util.isEqual(groupings[j][k]->get(i), 0)) { numNotZero++; }
                     }else {
-                        totalAbund += groupings[(it->second).groupIndex][(it->second).otuIndex]->get(i);
-                        if (groupings[(it->second).groupIndex][(it->second).otuIndex]->get(i) != 0.0) { numNotZero++; }
+                        float thisAbund = groupings[(it->second).groupIndex][(it->second).otuIndex]->get(i);
+                        totalAbund += thisAbund;
+                        if (!util.isEqual(thisAbund, 0)) { numNotZero++; }
                     }
                     
                 }
@@ -453,10 +454,10 @@ vector<float> getValues(vector< vector<SharedRAbundVector*> >& groupings, vector
                     
                     if (it == groupingsMap.end()) { //this one didnt get moved
                         totalAbund += groupings[j][k]->get(i);
-                        if (groupings[j][k]->get(i) != 0.0) { numNotZero++; }
+                        if (groupings[j][k]->get(i) != 0) { numNotZero++; }
                     }else {
                         totalAbund += groupings[(it->second).groupIndex][(it->second).otuIndex]->get(i);
-                        if (groupings[(it->second).groupIndex][(it->second).otuIndex]->get(i) != 0.0) { numNotZero++; }
+                        if (groupings[(it->second).groupIndex][(it->second).otuIndex]->get(i) != 0) { numNotZero++; }
                     }
                 }
                 
@@ -563,7 +564,7 @@ int IndicatorCommand::GetIndicatorSpecies(){
 				subset.clear();
 			}
 				
-			if (groupsAlreadyAdded.size() != data.size()) {  m->mothurOut("[ERROR]: could not make proper groupings."); m->mothurOutEndLine(); }
+			if (groupsAlreadyAdded.size() != data.size()) {  m->mothurOut("[ERROR]: could not make proper groupings.\n"); }
 				
 			indicatorValues = getValues(groupings, groupingNames, indicatorGroups, randomGroupingsMap, m);
 			
@@ -616,12 +617,9 @@ int IndicatorCommand::GetIndicatorSpecies(){
 			else { out << "<" << (1/(float)iters) << endl; }
 			
 			if (pValues[j] <= 0.05) {
-				cout << currentLabels[j] << '\t' << indicatorGroups[j] << '\t' << indicatorValues[j]  << '\t';
 				string pValueString = "<" + toString((1/(float)iters)); 
-				if (pValues[j] > (1/(float)iters)) { pValueString = toString(pValues[j]); cout << pValues[j];} 
-                else { cout << "<" << (1/(float)iters); }
-				m->mothurOutJustToLog(currentLabels[j] + "\t" + indicatorGroups[j] + "\t" + toString(indicatorValues[j]) + "\t" + pValueString);
-                m->mothurOutEndLine();
+				if (pValues[j] > (1/(float)iters)) { pValueString = toString(pValues[j]); }
+				m->mothurOut(currentLabels[j] + "\t" + indicatorGroups[j] + "\t" + toString(indicatorValues[j]) + "\t" + pValueString + "\n");
 			}
 		}
 		
@@ -844,12 +842,9 @@ int IndicatorCommand::GetIndicatorSpecies(Tree*& T){
 				}
 				
 				if (pValues[j] <= 0.05) {
-					cout << i+1 << '\t' << currentLabels[j] << '\t' << indicatorGroups[j] << '\t' << indicatorValues[j];
 					string pValueString = "\t<" + toString((1/(float)iters));
-					if (pValues[j] > (1/(float)iters)) { pValueString = toString('\t' + pValues[j]); cout << '\t' << pValues[j];}
-					else { cout << "\t<" << (1/(float)iters); }
-					m->mothurOutJustToLog(toString(i) + "\t" + currentLabels[j] + "\t" + indicatorGroups[j] + "\t" + toString(indicatorValues[j]) + "\t" + pValueString);
-					m->mothurOutEndLine(); 
+					if (pValues[j] > (1/(float)iters)) { pValueString = toString('\t' + pValues[j]); }
+					m->mothurOut(toString(i+1) + "\t" + currentLabels[j] + "\t" + indicatorGroups[j] + "\t" + toString(indicatorValues[j]) + "\t" + pValueString + "\n");
 				}
 			}
 			out << endl;
@@ -1352,7 +1347,7 @@ map<int, float> IndicatorCommand::getDistToRoot(Tree*& T){
             int index = i;
             
             while(T->tree[index].getParent() != -1){
-                if (T->tree[index].getBranchLength() != -1) {
+                if (!util.isEqual(T->tree[index].getBranchLength(), -1)) {
                     sum += abs(T->tree[index].getBranchLength());
                 }
                 index = T->tree[index].getParent();
