@@ -118,7 +118,7 @@ LefseCommand::LefseCommand(){
 LefseCommand::LefseCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;
-        allLines = 1;
+        allLines = true;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -192,8 +192,8 @@ LefseCommand::LefseCommand(string option)  {
             string label = validParameter.valid(parameters, "label");
 			if (label == "not found") { label = ""; }
 			else {
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
             
             mclass = validParameter.valid(parameters, "class");
@@ -757,7 +757,7 @@ map<int, double> LefseCommand::testLDA(SharedRAbundFloatVectors*& lookup, map<in
         }
                 
         //go through classes
-        int minCl = 1e6;
+        int minCl = MOTHURMAX;
         map<int, string> indexToClass;
         vector<string> classes;
         for (map<string, vector<int> >::iterator it = class2GroupIndex.begin(); it != class2GroupIndex.end(); it++) {
