@@ -176,7 +176,7 @@ MakeBiomCommand::MakeBiomCommand(){
 MakeBiomCommand::MakeBiomCommand(string option) {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
         
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -305,8 +305,8 @@ MakeBiomCommand::MakeBiomCommand(string option) {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 			
 			groups = validParameter.valid(parameters, "groups");			
@@ -363,7 +363,7 @@ int MakeBiomCommand::execute(){
         
         //if user did not specify a label, then use first one
         if ((contaxonomyfile != "") && (labels.size() == 0)) {
-            allLines = 0;
+            allLines = false;
             labels.insert(lastLabel);
         }
         
@@ -851,6 +851,11 @@ vector<string> MakeBiomCommand::getMetaData(SharedRAbundVectors*& lookup){
                 }
             }
             
+            //sanity check for file issues - do you have the same number of bins in the shared and constaxonomy file
+            if (lookup->getNumBins() != labelTaxMap.size()) {
+                m->mothurOut("[ERROR]: Your constaxonomy file contains " + toString(labelTaxMap.size()) + " otus and your shared file contain " + toString(lookup->getNumBins()) + " otus, cannot continue.\n"); m->setControl_pressed(true); return metadata;
+            }
+            
             //merges OTUs classified to same gg otuid, sets otulabels to gg otuids, averages confidence scores of merged otus.  overwritting of otulabels is fine because constaxonomy only allows for one label to be processed.  If this assumption changes, could cause bug.
             if (picrust) {  getGreenGenesOTUIDs(lookup, labelTaxMap);  }
             
@@ -1070,20 +1075,20 @@ int MakeBiomCommand::getGreenGenesOTUIDs(SharedRAbundVectors*& lookup, map<strin
             
         }
         
-        vector<SharedRAbundVector*> newLookup;
+        SharedRAbundVectors* newLookup = new SharedRAbundVectors();
         vector<string> namesOfGroups = lookup->getNamesGroups();
 		for (int i = 0; i < namesOfGroups.size(); i++) {
 			SharedRAbundVector* temp = new SharedRAbundVector();
 			temp->setLabel(lookup->getLabel());
 			temp->setGroup(namesOfGroups[i]);
-			newLookup.push_back(temp);
+			newLookup->push_back(temp);
 		}
 		
         map<string, int> labelIndex;
         vector<string> currentLabels = lookup->getOTUNames();
 		for (int i = 0; i < currentLabels.size(); i++) {  labelIndex[util.getSimpleLabel(currentLabels[i])] = i; }
         
-        vector<string> newBinLabels;
+        //vector<string> newBinLabels;
         map<string, string> newLabelTaxMap;
         //loop through ggOTUID list combining mothur otus and adjusting labels
         //ggOTUIDs = 16097 -> <OTU01, OTU10, OTU22>
@@ -1119,7 +1124,11 @@ int MakeBiomCommand::getGreenGenesOTUIDs(SharedRAbundVectors*& lookup, map<strin
                 
                 //merge abunds
                 mergeString += (itMap->second)[j] + " ";
-                for (int i = 0; i < lookup->size(); i++) { abunds[i] += lookup->get(labelIndex[util.getSimpleLabel((itMap->second)[j])], namesOfGroups[i]); }
+                string simpleLabel = util.getSimpleLabel((itMap->second)[j]);
+                int otuindex = labelIndex[simpleLabel];
+                vector<int> otuAbunds = lookup->getOTU(otuindex);
+                
+                for (int i = 0; i < otuAbunds.size(); i++) { abunds[i] += otuAbunds[i]; }
             }
             
             if (m->getDebug()) { m->mothurOut("[DEBUG]: merging " + mergeString + " for ggOTUid = " + itMap->first + ".\n");  }
@@ -1141,17 +1150,11 @@ int MakeBiomCommand::getGreenGenesOTUIDs(SharedRAbundVectors*& lookup, map<strin
             newLabelTaxMap[itMap->first] = newTaxString;
             
             //add merged otu to new lookup
-            for (int j = 0; j < abunds.size(); j++) { newLookup[j]->push_back(abunds[j]); }
-            
-            //saved otu label
-            newBinLabels.push_back(itMap->first);
+            newLookup->push_back(abunds, itMap->first);
         }
 		
-        lookup->clear();
-        for (int i = 0; i < newLookup.size(); i++) { lookup->push_back(newLookup[i]);  }
-        lookup->eliminateZeroOTUS();
-		
-		lookup->setOTUNames(newBinLabels);
+        delete lookup;
+        lookup = newLookup;
         labelTaxMap = newLabelTaxMap;
         
         map<string, string> variables;
