@@ -32,10 +32,13 @@ public:
 
 private:
     
-    string inputDir, outputDir, typeFile, prefix;
+    string inputDir, outputDir, typeFile, prefix, delim;
     vector<string> outputNames;
     int numCols;
     bool abort;
+    
+    vector< vector<string> > findGroupNames(vector< vector<string> > paired);
+    int fillAccnosFile(string tempFile);
 };
 
 
