@@ -22,6 +22,7 @@ vector<string> MatrixOutputCommand::setParameters(){
         CommandParameter pmode("mode", "Multiple", "average-median", "average", "", "", "","",false,false); parameters.push_back(pmode);
 		CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
         CommandParameter piters("iters", "Number", "", "1000", "", "", "","",false,false); parameters.push_back(piters);
+        CommandParameter pwithreplacement("withreplacement", "Boolean", "", "F", "", "", "","",false,false,true); parameters.push_back(pwithreplacement);
         CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
@@ -45,6 +46,7 @@ string MatrixOutputCommand::getHelpString(){
 		helpString += "The group names are separated by dashes. The label parameter allows you to select what distance levels you would like distance matrices created for, and is also separated by dashes.\n";
         helpString += "The iters parameter allows you to choose the number of times you would like to run the subsample.\n";
         helpString += "The subsample parameter allows you to enter the size pergroup of the sample or you can set subsample=T and mothur will use the size of your smallest group.\n";
+        helpString += "The withreplacement parameter allows you to indicate you want to subsample your data allowing for the same read to be included multiple times. Default=f. \n";
 		helpString += "The dist.shared command should be in the following format: dist.shared(groups=yourGroups, calc=yourCalcs, label=yourLabels).\n";
 		helpString += "The output parameter allows you to specify format of your distance matrix. Options are lt, column and square. The default is lt.\n";
         helpString += "The mode parameter allows you to specify if you want the average or the median values reported when subsampling. Options are average, and median. The default is average.\n";
@@ -94,7 +96,7 @@ MatrixOutputCommand::MatrixOutputCommand(){
 MatrixOutputCommand::MatrixOutputCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
 				
 		//allow user to run help
 		if(option == "help") {  help(); abort = true; calledHelp = true; }
@@ -136,8 +138,8 @@ MatrixOutputCommand::MatrixOutputCommand(string option)  {
 			if (sharedfile == "not found") { 			
 				//if there is a current shared file, use it
 				sharedfile = current->getSharedFile(); 
-				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter.\n");  }
+				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required.\n");  abort = true; }
 			}else if (sharedfile == "not open") { sharedfile = ""; abort = true; }
 			else { current->setSharedFile(sharedfile); }
 			
@@ -152,15 +154,15 @@ MatrixOutputCommand::MatrixOutputCommand(string option)  {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 			
 			output = validParameter.valid(parameters, "output");		if(output == "not found"){	output = "lt"; }
-			if ((output != "lt") && (output != "square") && (output != "column")) { m->mothurOut(output + " is not a valid output form. Options are lt, column and square. I will use lt."); m->mothurOutEndLine(); output = "lt"; }
+			if ((output != "lt") && (output != "square") && (output != "column")) { m->mothurOut(output + " is not a valid output form. Options are lt, column and square. I will use lt.\n"); output = "lt"; }
             
             mode = validParameter.valid(parameters, "mode");		if(mode == "not found"){	mode = "average"; }
-			if ((mode != "average") && (mode != "median")) { m->mothurOut(mode + " is not a valid mode. Options are average and medina. I will use average."); m->mothurOutEndLine(); output = "average"; }
+			if ((mode != "average") && (mode != "median")) { m->mothurOut(mode + " is not a valid mode. Options are average and medina. I will use average.\n");  output = "average"; }
 			
 			groups = validParameter.valid(parameters, "groups");			
 			if (groups == "not found") { groups = ""; }
@@ -194,7 +196,10 @@ MatrixOutputCommand::MatrixOutputCommand(string option)  {
                 else { subsample = false; }
             }
             
-            if (subsample == false) { iters = 0; }
+            if (subsample == false) { iters = 1; }
+            
+            temp = validParameter.valid(parameters, "withreplacement");		if (temp == "not found"){	temp = "f";		}
+            withReplacement = util.isTrue(temp);
             
         }
 	}
@@ -224,17 +229,18 @@ int MatrixOutputCommand::execute(){
 		set<string> processedLabels;
 		set<string> userLabels = labels;
 					
-        if (lookup->size() < 2) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command."); m->mothurOutEndLine(); delete lookup; return 0;}
+        if (lookup->size() < 2) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command.\n");  delete lookup; return 0;}
         
         if (subsample) { 
             if (subsampleSize == -1) { //user has not set size, set size = smallest samples size
                 subsampleSize = lookup->getNumSeqsSmallestGroup();
+                m->mothurOut("\nSetting sample size to " + toString(subsampleSize) + ".\n\n");
             }else {
                 lookup->removeGroups(subsampleSize);
                 Groups = lookup->getNamesGroups();
             }
             
-            if (lookup->size() < 2) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command."); m->mothurOutEndLine(); m->setControl_pressed(true);  return 0; }
+            if (lookup->size() < 2) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command.\n"); m->setControl_pressed(true);  return 0; }
         }
 		numGroups = lookup->size();
         
@@ -282,10 +288,10 @@ int MatrixOutputCommand::execute(){
 		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
 			m->mothurOut("Your file does not include the label " + *it);  
 			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
+				m->mothurOut(". I will use " + lastLabel + ".\n");
 				needToRun = true;
 			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
+				m->mothurOut(". Please refer to " + lastLabel + ".\n");
 			}
 		}
 		
@@ -310,13 +316,12 @@ int MatrixOutputCommand::execute(){
 		string currentName = "";
 		itTypes = outputTypes.find("phylip");
 		if (itTypes != outputTypes.end()) {
-			if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; if (!subsample) { current->setPhylipFile(currentName); } }
+			if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setPhylipFile(currentName);  }
 		}
 		
 		m->mothurOut("\nOutput File Names: \n"); 
 		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 
-
 		return 0;
 	}
 	catch(exception& e) {
@@ -498,18 +503,20 @@ int process(distSharedData* params){
         }
         
         //if the users entered no valid calculators don't execute command
-        if (matrixCalculators.size() == 0) { params->m->mothurOut("No valid calculators."); params->m->mothurOutEndLine();  return 0; }
+        if (matrixCalculators.size() == 0) { params->m->mothurOut("No valid calculators.\n");  return 0; }
         params->Estimators.clear();
         for (int i=0; i<matrixCalculators.size(); i++) { params->Estimators.push_back(matrixCalculators[i]->getName()); }
         
         vector< vector<seqDist>  > calcDists; calcDists.resize(matrixCalculators.size()); 		
         SubSample sample;
         for (int thisIter = 0; thisIter < params->numIters; thisIter++) {
-            
             SharedRAbundVectors* thisItersLookup = new SharedRAbundVectors(*params->thisLookup);
             vector<string> namesOfGroups = thisItersLookup->getNamesGroups();
             
-            if ((params->subsample && (!params->mainThread)) || (params->mainThread && (thisIter != 0) ) ) { sample.getSample(thisItersLookup, params->subsampleSize); }
+            if (params->subsample) {
+                if (params->withReplacement)    {  sample.getSampleWithReplacement(thisItersLookup, params->subsampleSize);     }
+                else                            {  sample.getSample(thisItersLookup, params->subsampleSize);                    }
+            }
             
             vector<SharedRAbundVector*> thisItersRabunds = thisItersLookup->getSharedRAbundVectors();
             vector<string> thisItersGroupNames = params->thisLookup->getNamesGroups();
@@ -517,7 +524,7 @@ int process(distSharedData* params){
             driver(thisItersRabunds, calcDists, matrixCalculators, params->m);
             
             for (int i = 0; i < thisItersRabunds.size(); i++) { delete thisItersRabunds[i]; }
-            if ((params->subsample && (!params->mainThread)) || (params->mainThread && (thisIter != 0) ) ){
+            if (params->subsample){
                 if((thisIter+1) % 100 == 0){	params->m->mothurOutJustToScreen(toString(thisIter+1)+"\n"); 		}
                 params->calcDistsTotals.push_back(calcDists);
                 for (int i = 0; i < calcDists.size(); i++) {
@@ -564,12 +571,12 @@ int MatrixOutputCommand::createProcesses(SharedRAbundVectors*& thisLookup){
         vector<string> groupNames = thisLookup->getNamesGroups();
         
         vector<int> lines;
-        if (processors > (iters+1)) { processors = iters+1; }
+        if (processors > (iters)) { processors = iters; }
         
         //figure out how many sequences you have to process
-        int numItersPerProcessor = (iters+1) / processors;
+        int numItersPerProcessor = (iters) / processors;
         for (int i = 0; i < processors; i++) {
-            if(i == (processors - 1)){	numItersPerProcessor = (iters+1) - i * numItersPerProcessor; 	}
+            if(i == (processors - 1)){	numItersPerProcessor = (iters) - i * numItersPerProcessor; 	}
             lines.push_back(numItersPerProcessor);
         }
         
@@ -582,7 +589,7 @@ int MatrixOutputCommand::createProcesses(SharedRAbundVectors*& thisLookup){
             
             //make copy of lookup so we don't get access violations
             SharedRAbundVectors* newLookup = new SharedRAbundVectors(*thisLookup);
-            distSharedData* dataBundle = new distSharedData(lines[i+1], false, subsample, subsampleSize, Estimators, newLookup);
+            distSharedData* dataBundle = new distSharedData(lines[i+1], false, subsample, subsampleSize, withReplacement, Estimators, newLookup);
             
             data.push_back(dataBundle);
             
@@ -591,30 +598,31 @@ int MatrixOutputCommand::createProcesses(SharedRAbundVectors*& thisLookup){
         
         //make copy of lookup so we don't get access violations
         SharedRAbundVectors* newLookup = new SharedRAbundVectors(*thisLookup);
-        distSharedData* dataBundle = new distSharedData(lines[0], true, subsample, subsampleSize, Estimators, newLookup);
+        distSharedData* dataBundle = new distSharedData(lines[0], true, subsample, subsampleSize, withReplacement, Estimators, newLookup);
         process(dataBundle);
         delete newLookup;
         
         Estimators.clear(); Estimators = dataBundle->Estimators;
         
-        map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
-        variables["[distance]"] = thisLookup->getLabel();
-        variables["[tag2]"] = "";
-        variables["[outputtag]"] = output;
-        
-        /// fix to print out matrices for each calc - only main does this
-        for (int i = 0; i < Estimators.size(); i++) {
-            variables["[calc]"] = Estimators[i];
-            string distFileName = getOutputFileName("phylip",variables);
-            outputNames.push_back(distFileName); outputTypes["phylip"].push_back(distFileName);
+        if (!subsample) {
+            map<string, string> variables;
+            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+            variables["[distance]"] = thisLookup->getLabel();
+            variables["[tag2]"] = "";
+            variables["[outputtag]"] = output;
             
-            ofstream outDist; util.openOutputFile(distFileName, outDist);
-            outDist.setf(ios::fixed, ios::floatfield); outDist.setf(ios::showpoint);
-            
-            printDists(outDist, dataBundle->matrices[i], groupNames); outDist.close();
+            /// fix to print out matrices for each calc - only main does this
+            for (int i = 0; i < Estimators.size(); i++) {
+                variables["[calc]"] = Estimators[i];
+                string distFileName = getOutputFileName("phylip",variables);
+                outputNames.push_back(distFileName); outputTypes["phylip"].push_back(distFileName);
+                
+                ofstream outDist; util.openOutputFile(distFileName, outDist);
+                outDist.setf(ios::fixed, ios::floatfield); outDist.setf(ios::showpoint);
+                
+                printDists(outDist, dataBundle->matrices[i], groupNames); outDist.close();
+            }
         }
-
         vector< vector< vector<seqDist> > > calcDistsTotals = dataBundle->calcDistsTotals;
         
         for (int i = 0; i < processors-1; i++) {
@@ -629,8 +637,7 @@ int MatrixOutputCommand::createProcesses(SharedRAbundVectors*& thisLookup){
         }
         delete dataBundle;
     
-        //main thread finds averages
-        if (iters != 0) {
+        if (subsample) {
             //we need to find the average distance and standard deviation for each groups distance
             vector< vector<seqDist>  > calcAverages = util.getAverages(calcDistsTotals, mode);
             
