@@ -97,7 +97,7 @@ MergeSfffilesCommand::MergeSfffilesCommand(string option)  {
 			ValidParameters validParameter;
 			//check to make sure all parameters are valid for command
 			for (map<string,string>::iterator it = parameters.begin(); it != parameters.end(); it++) {
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -145,39 +145,11 @@ MergeSfffilesCommand::MergeSfffilesCommand(string option)  {
 							if (path == "") {	filenames[i] = inputDir + filenames[i];		}
 						}
                         
-						ifstream in;
-						bool ableToOpen = util.openInputFile(filenames[i], in, "noerror");
+                        bool ableToOpen = util.checkLocations(filenames[i], current->getLocations());
                         
-						//if you can't open it, try default location
 						if (!ableToOpen) {
-							if (current->getDefaultPath() != "") { //default path is set
-								string tryPath = current->getDefaultPath() + util.getSimpleName(filenames[i]);
-								m->mothurOut("Unable to open " + filenames[i] + ". Trying default " + tryPath); m->mothurOutEndLine();
-								ifstream in2;
-								ableToOpen = util.openInputFile(tryPath, in2, "noerror");
-								in2.close();
-								filenames[i] = tryPath;
-							}
-						}
-						
-						//if you can't open it, try default location
-						if (!ableToOpen) {
-							if (current->getOutputDir() != "") { //default path is set
-								string tryPath = current->getOutputDir() + util.getSimpleName(filenames[i]);
-								m->mothurOut("Unable to open " + filenames[i] + ". Trying output directory " + tryPath); m->mothurOutEndLine();
-								ifstream in2;
-								ableToOpen = util.openInputFile(tryPath, in2, "noerror");
-								in2.close();
-								filenames[i] = tryPath;
-							}
-						}
-						
-						in.close();
-						
-						if (!ableToOpen) {
-							m->mothurOut("Unable to open " + filenames[i] + ". It will be disregarded."); m->mothurOutEndLine();
-							//erase from file list
-							filenames.erase(filenames.begin()+i);
+							m->mothurOut("Unable to open " + filenames[i] + ". It will be disregarded.\n");
+							filenames.erase(filenames.begin()+i); //erase from file list
 							i--;
 						}else { current->setSFFFile(filenames[i]); }
 					}
@@ -364,7 +336,6 @@ int MergeSfffilesCommand::readCommonHeader(ifstream& in, CommonHeader& header){
             char buffer6 [2];
             in.read(buffer6, 2);
             header.keyLength = be_int2(*(unsigned short *)(&buffer6));
-            //cout << "header key length = " << header.keyLength << endl;
             
             //read number of flow reads
             char buffer7 [2];
@@ -387,10 +358,9 @@ int MergeSfffilesCommand::readCommonHeader(ifstream& in, CommonHeader& header){
             char* tempBuffer2 = new char[header.keyLength];
             in.read(&(*tempBuffer2), header.keyLength);
             header.keySequence = tempBuffer2;
-            //cout << "key sequence " <<header.keySequence << endl;
+            
             if (header.keySequence.length() > header.keyLength) { header.keySequence = header.keySequence.substr(0, header.keyLength);  }
             delete[] tempBuffer2;
-            //cout << "key sequence " <<header.keySequence << endl;
             
             /* Pad to 8 chars */
             unsigned long long spotInFile = in.tellg();
@@ -773,35 +743,9 @@ int MergeSfffilesCommand::readFile(){
             
             if (m->getDebug()) { m->mothurOut("[DEBUG]: filename = " + filename + ".\n"); }
             
-            //check to make sure both are able to be opened
-            ifstream in2;
-            bool openForward = util.openInputFile(filename, in2, "noerror");
+            bool ableToOpen = util.checkLocations(filename, current->getLocations());
             
-            //if you can't open it, try default location
-            if (!openForward) {
-                if (current->getDefaultPath() != "") { //default path is set
-                    string tryPath = current->getDefaultPath() + util.getSimpleName(filename);
-                    m->mothurOut("Unable to open " + filename + ". Trying default " + tryPath); m->mothurOutEndLine();
-                    ifstream in3;
-                    openForward = util.openInputFile(tryPath, in3, "noerror");
-                    in3.close();
-                    filename = tryPath;
-                }
-            }
-            
-            //if you can't open it, try output location
-            if (!openForward) {
-                if (current->getOutputDir() != "") { //default path is set
-                    string tryPath = current->getOutputDir() + util.getSimpleName(filename);
-                    m->mothurOut("Unable to open " + filename + ". Trying output directory " + tryPath); m->mothurOutEndLine();
-                    ifstream in4;
-                    openForward = util.openInputFile(tryPath, in4, "noerror");
-                    filename = tryPath;
-                    in4.close();
-                }
-            }
-            
-            if (!openForward) { //can't find it
+            if (!ableToOpen) { //can't find it
                 m->mothurOut("[WARNING]: can't find " + filename + ", ignoring.\n");
             }else{  filenames.push_back(filename); }
             
