@@ -125,7 +125,7 @@ MGClusterCommand::MGClusterCommand(string option) {
 		
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -303,7 +303,6 @@ int MGClusterCommand::execute(){
 void MGClusterCommand::printData(ListVector* mergedList, map<string, int>& counts, bool& ph){
 	try {
         mergedList->setPrintedLabels(ph); ph = false;
-        
         if (countfile != "") {
             mergedList->print(listFile, counts);
         }else { mergedList->print(listFile, true); }
@@ -337,9 +336,7 @@ int MGClusterCommand::runOptiCluster(){
         
         time_t start = time(NULL);
         
-        OptiMatrix matrix;
-        matrix.setBlastVariables(length, penalty, minWanted);
-        matrix.readFile(distfile, thisNamefile, nameOrCount, "blast", cutoff, false);
+        OptiData* matrix; matrix = new OptiBlastMatrix(distfile, thisNamefile, nameOrCount, false, cutoff, length, penalty, minWanted);
         
         ClusterMetric* metricCalc = NULL;
         if (metric == "mcc")             { metricCalc = new MCC();              }
@@ -357,7 +354,7 @@ int MGClusterCommand::runOptiCluster(){
         else if (metric == "fdr")        { metricCalc = new FDR();              }
         else if (metric == "fpfn")       { metricCalc = new FPFN();             }
         
-        OptiCluster cluster(&matrix, metricCalc, 0);
+        OptiCluster cluster(matrix, metricCalc, 0);
         string tag = cluster.getTag();
         
         map<string, string> variables;
@@ -425,26 +422,26 @@ int MGClusterCommand::runOptiCluster(){
         list->setLabel(toString(cutoff));
         
         if (merge) {
-            vector< set<int> > overlap = matrix.getBlastOverlap();
+            vector< set<long long> > overlap = matrix->getBlastOverlap();
         
             //assign each sequence to bins
-            map<string, int> seqToBin;
-            for (int i = 0; i < list->getNumBins(); i++) {
+            map<string, long long> seqToBin;
+            for (long long i = 0; i < list->getNumBins(); i++) {
                 if (m->getControl_pressed()) { break; }
                 string bin = list->get(i);
                 vector<string> names; util.splitAtComma(bin, names);
-                for (int j = 0; j < names.size(); j++) { seqToBin[names[j]] = i; }
+                for (long long j = 0; j < names.size(); j++) { seqToBin[names[j]] = i; }
             }
             
             //merge overlapping bins
-            int mergedBinCount = 0;
-            for (int i = 0; i < overlap.size(); i++) {
-                set<int> temp = overlap[i]; overlap[i].clear();
-                for (set<int>::iterator itOverlap = temp.begin(); itOverlap != temp.end(); itOverlap++) {
-                    string firstName = matrix.getOverlapName(i);
-                    string secondName = matrix.getOverlapName(*itOverlap);
-                    int binKeep = seqToBin[firstName];
-                    int binRemove = seqToBin[secondName];
+            long long mergedBinCount = 0;
+            for (long long i = 0; i < overlap.size(); i++) {
+                set<long long> temp = overlap[i]; overlap[i].clear();
+                for (set<long long>::iterator itOverlap = temp.begin(); itOverlap != temp.end(); itOverlap++) {
+                    string firstName = matrix->getOverlapName(i);
+                    string secondName = matrix->getOverlapName(*itOverlap);
+                    long long binKeep = seqToBin[firstName];
+                    long long binRemove = seqToBin[secondName];
                     
                     if(binKeep != binRemove) {
                         //save names in old bin
@@ -505,8 +502,10 @@ int MGClusterCommand::runOptiCluster(){
         sensFile << '\n';
         sensFile.close();
         
-        m->mothurOut("It took " + toString(time(NULL) - start) + " seconds to cluster."); m->mothurOutEndLine();
+        m->mothurOut("It took " + toString(time(NULL) - start) + " seconds to cluster.\n");
 
+        delete metricCalc; delete matrix;
+        
         return 0;
     }
     catch(exception& e) {
@@ -604,7 +603,7 @@ int MGClusterCommand::runMothurCluster(){
         
         
         //cluster using cluster classes
-        while (distMatrix->getSmallDist() < cutoff && distMatrix->getNNodes() > 0){
+        while (distMatrix->getSmallDist() <= cutoff && distMatrix->getNNodes() > 0){
             
             if (m->getDebug()) {  cout << "numNodes=" << distMatrix->getNNodes() << " smallDist = " << distMatrix->getSmallDist() << endl; }
             
@@ -620,11 +619,11 @@ int MGClusterCommand::runMothurCluster(){
             float dist = distMatrix->getSmallDist();
             float rndDist = util.ceilDist(dist, precision);
             
-            if(previousDist <= 0.0000 && dist != previousDist){
+            if(previousDist <= 0.0000 && !util.isEqual(dist, previousDist)){
                 oldList.setLabel("unique");
                 printData(&oldList, counts, printHeaders);
             }
-            else if(rndDist != rndPreviousDist){
+            else if(!util.isEqual(rndDist, rndPreviousDist)){
                 if (merge) {
                     ListVector* temp = mergeOPFs(oldSeq2Bin, rndPreviousDist);
                     
@@ -694,7 +693,7 @@ int MGClusterCommand::runMothurCluster(){
             return 0; 
         }
         
-        if (saveCutoff != cutoff) {
+        if (!util.isEqual(saveCutoff, cutoff)) {
             saveCutoff = util.ceilDist(saveCutoff, precision);
             m->mothurOut("changed cutoff to " + toString(cutoff)); m->mothurOutEndLine();
         }
