@@ -116,7 +116,7 @@ PrimerDesignCommand::PrimerDesignCommand(string option)  {
 			map<string,string>::iterator it;
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
             vector<string> tempOutNames;
@@ -316,17 +316,17 @@ int PrimerDesignCommand::execute(){
             
             double minTm, maxTm;
             findMeltingPoint(*it, minTm, maxTm);
-            if ((minTM == -1) && (maxTM == -1)) { //user did not set min or max Tm so save this primer
+            if (util.isEqual(minTM, -1) && util.isEqual(maxTM, -1)) { //user did not set min or max Tm so save this primer
                 minTms.push_back(minTm);
                 maxTms.push_back(maxTm);
                 outSum << *it << '\t' << minTm << '\t' << maxTm << endl;
                 it++;
-            }else if ((minTM == -1) && (maxTm <= maxTM)){ //user set max and no min, keep if below max
+            }else if (util.isEqual(minTM, -1) && (maxTm <= maxTM)){ //user set max and no min, keep if below max
                 minTms.push_back(minTm);
                 maxTms.push_back(maxTm);
                 outSum << *it << '\t' << minTm << '\t' << maxTm << endl;
                 it++;
-            }else if ((maxTM == -1) && (minTm >= minTM)){ //user set min and no max, keep if above min
+            }else if (util.isEqual(maxTM, -1) && (minTm >= minTM)){ //user set min and no max, keep if above min
                 minTms.push_back(minTm);
                 maxTms.push_back(maxTm);
                 outSum << *it << '\t' << minTm << '\t' << maxTm << endl;
@@ -896,7 +896,7 @@ vector<Sequence> PrimerDesignCommand::createProcessesConSeqs(map<string, int>& n
 
         //Lauch worker threads
         for (int i = 0; i < processors-1; i++) {
-            if (m->getControl_pressed()) {  cout << " control pressed " << "\n"; break; }
+            if (m->getControl_pressed()) {  break; }
             
             primerCountsData* dataBundle = new primerCountsData(fastafile, nameMap, lines[i+1].start, lines[i+1].end, seq2Bin, numBins);
             data.push_back(dataBundle);
@@ -916,7 +916,7 @@ vector<Sequence> PrimerDesignCommand::createProcessesConSeqs(map<string, int>& n
             workerThreads[i]->join();
             total += data[i]->total;
             
-            if (m->getControl_pressed()) {  cout << " control pressed " << "\n"; break; }
+            if (m->getControl_pressed()) {  break; }
             
             if (data[i]->alignedLength != alignedLength) {  m->mothurOut("[ERROR]: your sequences are not all the same length. primer.design requires sequences to be aligned.\n"); m->setControl_pressed(true); }
             
