@@ -101,7 +101,7 @@ RemoveRareCommand::RemoveRareCommand(){
 RemoveRareCommand::RemoveRareCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -255,8 +255,8 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 			
 			string temp = validParameter.valid(parameters, "nseqs");
