@@ -94,7 +94,7 @@ SensSpecCommand::SensSpecCommand(string option)  {
 	try {
 
 		abort = false; calledHelp = false;
-		allLines = 1;
+		allLines = true;
 
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -246,8 +246,8 @@ SensSpecCommand::SensSpecCommand(string option)  {
 			string label = validParameter.valid(parameters, "label");
 			if (label == "not found") { label = ""; }
 			else {
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 
             map<string, string> variables;
