@@ -91,7 +91,7 @@ SharedCommand::SharedCommand(){
 SharedCommand::SharedCommand(string option)  {
 	try {
         abort = false; calledHelp = false; pickedGroups=false;
-		allLines = 1;
+		allLines = true;
 
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -253,8 +253,8 @@ SharedCommand::SharedCommand(string option)  {
 			 string label = validParameter.valid(parameters, "label");
 			 if (label == "not found") { label = ""; }
 			 else {
-				 if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				 else { allLines = 1;  }
+				 if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				 else { allLines = true;  }
 			 }
             
             if ((listfile == "") && (biomfile == "") && (countfile != "")) { //building a shared file from a count file, require label
@@ -326,13 +326,22 @@ int SharedCommand::createSharedFromCount() {
         
         CountTable ct;  ct.readTable(countfile, true, false);
         
-        SharedRAbundVectors* lookup = ct.getShared(Groups);
+        map<string, string> seqNameToOtuName;
+        SharedRAbundVectors* lookup = ct.getShared(Groups, seqNameToOtuName);
         lookup->setLabels(*labels.begin());
         lookup->print(out, printHeaders);
         
         out.close();
         delete lookup;
         
+        string mapFilename = getOutputFileName("map",variables);
+        outputNames.push_back(mapFilename); outputTypes["map"].push_back(mapFilename);
+        ofstream outMap;
+        util.openOutputFile(mapFilename, outMap);
+        
+        for (map<string, string>::iterator it = seqNameToOtuName.begin(); it != seqNameToOtuName.end(); it++) { outMap << it->first << '\t' << it->second << endl; }
+        outMap.close();
+        
         return 0;
     }
     catch(exception& e) {
