@@ -91,7 +91,7 @@ SparccCommand::SparccCommand(){
 SparccCommand::SparccCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;
-        allLines = 1;
+        allLines = true;
 
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -175,8 +175,8 @@ SparccCommand::SparccCommand(string option)  {
             string label = validParameter.valid(parameters, "label");
 			if (label == "not found") { label = ""; }
 			else {
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 		}
 
