@@ -44,6 +44,7 @@ vector<string> SummaryCommand::setParameters(){
 		CommandParameter psabund("sabund", "InputTypes", "", "", "LRSS", "LRSS", "none","summary",false,false); parameters.push_back(psabund);
 		CommandParameter pshared("shared", "InputTypes", "", "", "LRSS", "LRSS", "none","summary",false,false,true); parameters.push_back(pshared);
         CommandParameter psubsample("subsample", "String", "", "", "", "", "","",false,false); parameters.push_back(psubsample);
+        CommandParameter pwithreplacement("withreplacement", "Boolean", "", "F", "", "", "","",false,false,true); parameters.push_back(pwithreplacement);
         CommandParameter piters("iters", "Number", "", "1000", "", "", "","",false,false); parameters.push_back(piters);
 		CommandParameter plabel("label", "String", "", "", "", "", "","",false,false); parameters.push_back(plabel);
 		CommandParameter pcalc("calc", "Multiple", "sobs-chao-nseqs-coverage-ace-jack-shannon-shannoneven-npshannon-heip-smithwilson-simpson-simpsoneven-invsimpson-bootstrap-geometric-qstat-logseries-bergerparker-bstick-goodscoverage-efron-boneh-solow-shen", "sobs-chao-ace-jack-shannon-npshannon-simpson-shannonrange", "", "", "","",true,false,true); parameters.push_back(pcalc);
@@ -75,6 +76,7 @@ string SummaryCommand::getHelpString(){
 		helpString += "Example summary.single(label=unique-.01-.03, calc=sobs-chao-ace-jack-bootstrap-shannon-npshannon-simpson).\n";
 		helpString += validCalculator.printCalc("summary");
         helpString += "The subsample parameter allows you to enter the size of the sample or you can set subsample=T and mothur will use the size of your smallest group in the case of a shared file. With a list, sabund or rabund file you must provide a subsample size.\n";
+        helpString += "The withreplacement parameter allows you to indicate you want to subsample your data allowing for the same read to be included multiple times. Default=f. \n";
         helpString += "The iters parameter allows you to choose the number of times you would like to run the subsample. Default=1000.\n";
 		helpString += "The default value calc is sobs-chao-ace-jack-shannon-npshannon-simpson\n";
 		helpString += "If you are running summary.single with a shared file and would like your summary results collated in one file, set groupmode=t. (Default=true).\n";
@@ -120,7 +122,7 @@ SummaryCommand::SummaryCommand(){
 SummaryCommand::SummaryCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
 				
 		//allow user to run help
 		if(option == "help") {  help();  abort = true; calledHelp = true; }
@@ -208,18 +210,18 @@ SummaryCommand::SummaryCommand(string option)  {
 				//give priority to shared, then list, then rabund, then sabund
 				//if there is a current shared file, use it
 				sharedfile = current->getSharedFile(); 
-				if (sharedfile != "") { inputfile = sharedfile; format = "sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
+				if (sharedfile != "") { inputfile = sharedfile; format = "sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter.\n"); }
 				else { 
 					listfile = current->getListFile(); 
-					if (listfile != "") { inputfile = listfile; format = "list"; m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
+					if (listfile != "") { inputfile = listfile; format = "list"; m->mothurOut("Using " + listfile + " as input file for the list parameter.\n");  }
 					else { 
 						rabundfile = current->getRabundFile(); 
-						if (rabundfile != "") { inputfile = rabundfile; format = "rabund"; m->mothurOut("Using " + rabundfile + " as input file for the rabund parameter."); m->mothurOutEndLine(); }
+						if (rabundfile != "") { inputfile = rabundfile; format = "rabund"; m->mothurOut("Using " + rabundfile + " as input file for the rabund parameter.\n");  }
 						else { 
 							sabundfile = current->getSabundFile(); 
-							if (sabundfile != "") { inputfile = sabundfile; format = "sabund"; m->mothurOut("Using " + sabundfile + " as input file for the sabund parameter."); m->mothurOutEndLine(); }
+							if (sabundfile != "") { inputfile = sabundfile; format = "sabund"; m->mothurOut("Using " + sabundfile + " as input file for the sabund parameter.\n"); }
 							else { 
-								m->mothurOut("No valid current files. You must provide a list, sabund, rabund or shared file before you can use the collect.single command."); m->mothurOutEndLine(); 
+								m->mothurOut("No valid current files. You must provide a list, sabund, rabund or shared file before you can use the collect.single command.\n");
 								abort = true;
 							}
 						}
@@ -235,8 +237,8 @@ SummaryCommand::SummaryCommand(string option)  {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 				
 			calc = validParameter.valid(parameters, "calc");			
@@ -271,10 +273,13 @@ SummaryCommand::SummaryCommand(string option)  {
                 else { subsample = false; subsampleSize = -1; }
             }
             
+            temp = validParameter.valid(parameters, "withreplacement");		if (temp == "not found"){	temp = "f";		}
+            withReplacement = util.isTrue(temp);
+            
             temp = validParameter.valid(parameters, "alpha");		if (temp == "not found") { temp = "1"; }
 			util.mothurConvert(temp, alpha);
             
-            if ((alpha != 0) && (alpha != 1) && (alpha != 2)) { m->mothurOut("[ERROR]: Not a valid alpha value. Valid values are 0, 1 and 2."); m->mothurOutEndLine(); abort=true; }
+            if ((alpha != 0) && (alpha != 1) && (alpha != 2)) { m->mothurOut("[ERROR]: Not a valid alpha value. Valid values are 0, 1 and 2.\n");  abort=true; }
             
             if (!subsample) { iters = 0; }
             else {
@@ -318,7 +323,7 @@ int SummaryCommand::execute(){
             outputNames.push_back(fileNameRoot); outputTypes["summary"].push_back(fileNameRoot);
             
 			if (inputFileNames.size() > 1) {
-				m->mothurOutEndLine(); m->mothurOut("Processing group " + groups[p]); m->mothurOutEndLine(); m->mothurOutEndLine();
+				m->mothurOut("\nProcessing group " + groups[p] + "\n\n");
                 groupIndex[fileNameRoot] = groups[p];
 			}
 			
@@ -427,8 +432,6 @@ int SummaryCommand::execute(){
 			set<string> processedLabels;
 			set<string> userLabels = labels;
 			
-            
-            
 			if (m->getControl_pressed()) {  outputFileHandle.close(); outAve.close(); for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  } for(int i=0;i<sumCalculators.size();i++){  delete sumCalculators[i]; }  delete sabund;    return 0;  }
 			
 			while((sabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
@@ -437,7 +440,7 @@ int SummaryCommand::execute(){
 				
 				if(allLines == 1 || labels.count(sabund->getLabel()) == 1){			
 					
-					m->mothurOut(sabund->getLabel()); m->mothurOutEndLine();
+					m->mothurOut(sabund->getLabel()+"\n");
 					processedLabels.insert(sabund->getLabel());
 					userLabels.erase(sabund->getLabel());
 					
@@ -453,7 +456,7 @@ int SummaryCommand::execute(){
 					delete sabund;
 					sabund = input.getSAbundVector(lastLabel);
 					
-					m->mothurOut(sabund->getLabel()); m->mothurOutEndLine();
+					m->mothurOut(sabund->getLabel()+"\n");
 					processedLabels.insert(sabund->getLabel());
 					userLabels.erase(sabund->getLabel());
 					
@@ -480,10 +483,10 @@ int SummaryCommand::execute(){
 			for (it = userLabels.begin(); it != userLabels.end(); it++) {  
 				m->mothurOut("Your file does not include the label " + *it); 
 				if (processedLabels.count(lastLabel) != 1) {
-					m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
+					m->mothurOut(". I will use " + lastLabel + ".\n");
 					needToRun = true;
 				}else {
-					m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
+					m->mothurOut(". Please refer to " + lastLabel + ".\n");
 				}
 			}
 			
@@ -492,7 +495,7 @@ int SummaryCommand::execute(){
 				if (sabund != NULL) {	delete sabund;	}
 				sabund = input.getSAbundVector(lastLabel);
 				
-				m->mothurOut(sabund->getLabel()); m->mothurOutEndLine();
+				m->mothurOut(sabund->getLabel()+"\n");
                 process(sabund, outputFileHandle, outAve);
                 
                 if (m->getControl_pressed()) { outputFileHandle.close(); outAve.close(); for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);  } for(int i=0;i<sumCalculators.size();i++){  delete sumCalculators[i]; }  delete sabund;  return 0;  }
@@ -546,7 +549,9 @@ int SummaryCommand::process(SAbundVector*& sabund, ofstream& outputFileHandle, o
                 SAbundVector* newSabund = new SAbundVector();
                 *newSabund = rabund.getSAbundVector();
                 
-                sample.getSample(newSabund, subsampleSize);
+                if (withReplacement)    {  sample.getSampleWithReplacement(newSabund, subsampleSize);   }
+                else                    {  sample.getSample(newSabund, subsampleSize);                  }
+                
                 thisIterSabund = newSabund;
             }
             
@@ -642,10 +647,10 @@ vector<string> SummaryCommand::parseSharedFile(string filename) {
         /******************************************************/
         //user has not set size, set size = smallest samples size
         if (subsample) { 
-            if (subsampleSize == -1) { subsampleSize = lookup->getNumSeqsSmallestGroup(); }
+            if (subsampleSize == -1) { subsampleSize = lookup->getNumSeqsSmallestGroup();   m->mothurOut("\nSetting subsample size to " + toString(subsampleSize) + ".\n"); }
             else { lookup->removeGroups(subsampleSize); }
             
-            if (lookup->size() < 1) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command."); m->mothurOutEndLine(); m->setControl_pressed(true);  return filenames; }
+            if (lookup->size() < 1) { m->mothurOut("You have not provided enough valid groups.  I cannot run the command.\n");  m->setControl_pressed(true);  return filenames; }
         }
 		/******************************************************/
         
