@@ -96,7 +96,7 @@ SummaryQualCommand::SummaryQualCommand(string option)  {
 			
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
@@ -342,9 +342,7 @@ long long SummaryQualCommand::createProcessesCreateSummary(vector<int>& position
         positions = util.divideFile(filename, processors);
         for (int i = 0; i < (positions.size()-1); i++) {	lines.push_back(linePair(positions[i], positions[(i+1)]));	}
 #else
-        if (processors == 1) {
-            lines.push_back(linePair(0, 1000));
-        }else {
+        
             positions = util.setFilePosFasta(qualfile, numSeqs);
             if (numSeqs < processors) { processors = numSeqs; }
             
@@ -355,7 +353,7 @@ long long SummaryQualCommand::createProcessesCreateSummary(vector<int>& position
                 if(i == (processors - 1)){	numSeqsPerProcessor = numSeqs - i * numSeqsPerProcessor; 	}
                 lines.push_back(linePair(positions[startIndex], numSeqsPerProcessor));
             }
-        }
+        
 #endif
 
         //create array of worker threads
