@@ -105,7 +105,7 @@ SummaryTaxCommand::SummaryTaxCommand(string option)  {
 			
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//if the user changes the input directory command factory will send this info to us in the output parameter 
@@ -346,11 +346,10 @@ string SummaryTaxCommand::processTaxMap(string tax) {
                     newtaxon = taxon;
                     confidence = "-1";
                 }
-                float con = 0;
                 
-                util.mothurConvert(confidence, con);
+                float con = 0; util.mothurConvert(confidence, con);
                 
-                if (con == -1) { i += taxLength; } //not a confidence score, no confidence scores on this taxonomy
+                if (util.isEqual(con, -1)) { i += taxLength; } //not a confidence score, no confidence scores on this taxonomy
                 else if ( con < threshold)  { spot = i; break; } //below threshold, set all to unclassified
                 else {} //acceptable, move on
                 taxons.push_back(taxon);
