@@ -102,7 +102,7 @@ VennCommand::VennCommand(){
 VennCommand::VennCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;   
-		allLines = 1;
+		allLines = true;
 			
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -179,8 +179,8 @@ VennCommand::VennCommand(string option)  {
 			label = validParameter.valid(parameters, "label");			
 			if (label == "not found") { label = ""; }
 			else { 
-				if(label != "all") {  util.splitAtDash(label, labels);  allLines = 0;  }
-				else { allLines = 1;  }
+				if(label != "all") {  util.splitAtDash(label, labels);  allLines = false;  }
+				else { allLines = true;  }
 			}
 			
 			groups = validParameter.valid(parameters, "groups");			
