@@ -13,6 +13,8 @@
 #include "mothur.h"
 #include "sequence.hpp"
 #include "database.hpp"
+#include "utils.hpp"
+#include "currentfile.h"
 
 /**************************************************************************************************/
 
@@ -24,11 +26,11 @@ public:
 	AlignmentDB(string);
 	~AlignmentDB();
 	
-	Sequence findClosestSequence(Sequence*);
-	float getSearchScore()  {  return search->getSearchScore();  }
+	Sequence findClosestSequence(Sequence*, float&); //sequence to align, searchScore
 	int getLongestBase()	{  return longest;  }
 	
 private:
+    std::mutex mutex;
 	int numSeqs, longest, threadID;
 	string method;
 	
@@ -36,6 +38,8 @@ private:
 	vector<Sequence> templateSequences;
 	Sequence emptySequence;
 	MothurOut* m;
+    CurrentFile* current;
+    
 };
 
 /**************************************************************************************************/
