@@ -12,7 +12,7 @@
 
 
 #include "mothur.h"
-#include "dist.h"
+#include "calculator.h"
 
 class DistanceDB : public Database {
 	
@@ -24,11 +24,11 @@ public:
 	void generateDB() {} //doesn't generate a search db 
 	void addSequence(Sequence); 
 	string getName(int i) { return data[i].getName(); } 
-	vector<int> findClosestSequences(Sequence*, int);  // returns indexes of n closest sequences to query
+	vector<int> findClosestSequences(Sequence*, int, vector<float>&);  // returns indexes of n closest sequences to query
 	
 private:
 	vector<Sequence> data;
-	Dist* distCalculator;
+	DistCalc* distCalculator;
 	
 	int templateSeqsLength;
 	bool templateAligned;
