@@ -14,7 +14,6 @@
  GroupMap::GroupMap(string filename) {
 	m = MothurOut::getInstance();
 	groupFileName = filename;
-	util.openInputFile(filename, fileHandle);
 	index = 0;
 }
 
@@ -47,8 +46,87 @@ int GroupMap::addSeq(string name, string group) {
     }
 }
 /************************************************************/
+int GroupMap::readMap(string filename, vector<string> g) {
+    try {
+        groupFileName = filename;
+        
+        return (readMap(g));
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "readMap");
+        exit(1);
+    }
+}
+/************************************************************/
+int GroupMap::readMap(vector<string> g) {
+    try {
+        int error = 0;
+        
+        if (g.size() == 0) { return readMap(); }
+        else {
+            if (groupFileName == "") { m->mothurOut("[ERROR]: missing groupfile name, aborting.\n");  m->setControl_pressed(true); return 0; }
+            
+            ifstream fileHandle;
+            util.openInputFile(groupFileName, fileHandle);
+            
+            string header = util.getline(fileHandle);
+            vector<string> pieces = util.splitWhiteSpace(header);
+            string seqName = pieces[0];
+            string seqGroup = pieces[1];
+            if (seqName != "group") { //first group, not header
+                if (util.inUsersGroups(seqGroup, g)) {
+                    util.checkGroupName(seqGroup);
+                    setNamesOfGroups(seqGroup);
+                    
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
+                    it = groupmap.find(seqName);
+                    
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("[ERROR]: Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");  }
+                    else {
+                        groupmap[seqName] = seqGroup;	//store data in map
+                        seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
+                    }
+                }
+            }
+            
+            while (!fileHandle.eof()) {
+                if (m->getControl_pressed()) { fileHandle.close();  return 1; }
+                
+                fileHandle >> seqName; util.gobble(fileHandle);
+                fileHandle >> seqGroup; util.gobble(fileHandle);
+                
+                if (util.inUsersGroups(seqGroup, g)) {
+                    util.checkGroupName(seqGroup);
+                    setNamesOfGroups(seqGroup);
+                    
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
+                    util.checkName(seqName);
+                    it = groupmap.find(seqName);
+                    
+                    if (it != groupmap.end()) { error = 1; m->mothurOut("[ERROR]: Your groupfile contains more than 1 sequence named " + seqName + ", sequence names must be unique. Please correct.\n");  }
+                    else {
+                        groupmap[seqName] = seqGroup;	//store data in map
+                        seqsPerGroup[seqGroup]++;  //increment number of seqs in that group
+                    }
+                }
+            }
+            fileHandle.close();
+        }
+        
+        return error;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "readMap");
+        exit(1);
+    }
+}
+/************************************************************/
 int GroupMap::readMap() {
     try {
+        
+        if (groupFileName == "") { m->mothurOut("[ERROR]: missing groupfile name, aborting.\n");  m->setControl_pressed(true); return 0; }
+        
         string seqName, seqGroup;
 		int error = 0;
         string rest = "";
@@ -56,6 +134,9 @@ int GroupMap::readMap() {
         bool pairDone = false;
         bool columnOne = true;
         
+        ifstream fileHandle;
+        util.openInputFile(groupFileName, fileHandle);
+        
         string header = util.getline(fileHandle);
         vector<string> pieces = util.splitWhiteSpace(header);
         seqName = pieces[0];
@@ -146,6 +227,12 @@ int GroupMap::readDesignMap() {
         bool pairDone = false;
         bool columnOne = true;
         
+        if (groupFileName == "") { m->mothurOut("[ERROR]: missing groupfile name, aborting.\n");  m->setControl_pressed(true); return 0; }
+        
+        ifstream fileHandle;
+        util.openInputFile(groupFileName, fileHandle);
+
+        
         while (!fileHandle.eof()) {
             if (m->getControl_pressed()) { fileHandle.close();  return 1; }
             
@@ -212,6 +299,7 @@ int GroupMap::readDesignMap() {
 int GroupMap::readMap(string filename) {
     try {
         groupFileName = filename;
+        ifstream fileHandle;
         util.openInputFile(filename, fileHandle);
         index = 0;
         string seqName, seqGroup;
@@ -286,6 +374,7 @@ int GroupMap::readMap(string filename) {
 int GroupMap::readDesignMap(string filename) {
     try {
         groupFileName = filename;
+        ifstream fileHandle;
         util.openInputFile(filename, fileHandle);
         index = 0;
         string seqName, seqGroup;
@@ -368,11 +457,67 @@ string GroupMap::getGroup(string sequenceName) {
 	}else {
         //look for it in names of groups to see if the user accidently used the wrong file
         if (util.inUsersGroups(sequenceName, namesOfGroups)) {
-            m->mothurOut("[WARNING]: Your group or design file contains a group named " + sequenceName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group."); m->mothurOutEndLine(); 
+            m->mothurOut("[WARNING]: Your group or design file contains a group named " + sequenceName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group.\n");
         }
 		return "not found";
 	}
 }
+/************************************************************/
+vector<string> GroupMap::getGroups(string sequenceNames) {
+    try{
+        vector<string> names; util.splitAtComma(sequenceNames, names);
+        
+        return (getGroups(names));
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "getGroups");
+        exit(1);
+    }
+}
+/************************************************************/
+vector<string> GroupMap::getGroups(vector<string> sequenceNames) {
+    try{
+        set<string> repGroups;
+        for (int i = 0; i < sequenceNames.size(); i++) {
+            repGroups.insert(getGroup(sequenceNames[i]));
+        }
+        
+        return (util.mothurConvert(repGroups));
+        
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "getGroups");
+        exit(1);
+    }
+}
+/************************************************************/
+int GroupMap::getNumSeqs(string sequenceNames, string group) {
+    try{
+        vector<string> names; util.splitAtComma(sequenceNames, names);
+        
+        return (getNumSeqs(names, group));
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "getGroups");
+        exit(1);
+    }
+}
+/************************************************************/
+int GroupMap::getNumSeqs(vector<string> sequenceNames, string group) {
+    try{
+        int count = 0;
+        for (int i = 0; i < sequenceNames.size(); i++) {
+            if (group == getGroup(sequenceNames[i])) { count++; }
+        }
+        
+        return count;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "getGroups");
+        exit(1);
+    }
+}
+
 
 /************************************************************/
 
@@ -456,6 +601,23 @@ int GroupMap::getNumSeqs(string group) {
 	}
 }
 /************************************************************/
+int GroupMap::getNumSeqsSmallestGroup() {
+    try {
+        
+        int smallestGroup = MOTHURMAX;
+        
+        for (map<string, int>::iterator itNum = seqsPerGroup.begin(); itNum != seqsPerGroup.end(); itNum++) {
+            if (itNum->second < smallestGroup) {  smallestGroup = itNum->second; }
+        }
+    
+        return smallestGroup;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "getNumSeqsSmallestGroup");
+        exit(1);
+    }
+}
+/************************************************************/
 int GroupMap::renameSeq(string oldName, string newName) {
 	try {
 		
@@ -482,6 +644,24 @@ int GroupMap::renameSeq(string oldName, string newName) {
 	}
 }
 /************************************************************/
+int GroupMap::print(string outputName) {
+    try {
+        ofstream out;
+        util.openOutputFile(outputName, out);
+        
+        for (map<string, string>::iterator itName = groupmap.begin(); itName != groupmap.end(); itName++) {
+            out << itName->first << '\t' << itName->second << endl;
+        }
+        out.close();
+        
+        return 0;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "print");
+        exit(1);
+    }
+}
+/************************************************************/
 int GroupMap::print(ofstream& out) {
 	try {
 		
@@ -552,6 +732,25 @@ vector<string> GroupMap::getNamesSeqs(vector<string> picked){
 		exit(1);
 	}
 }
-
+/************************************************************/
+vector<string> GroupMap::getNamesSeqs(string picked){
+    try {
+        
+        vector<string> names;
+        
+        for (it = groupmap.begin(); it != groupmap.end(); it++) {
+            //if you are belong to one the the groups in the picked vector add you
+            if (it->second == picked) {
+                names.push_back(it->first);
+            }
+        }
+        
+        return names;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "getNamesSeqs");
+        exit(1);
+    }
+}
 /************************************************************/
 
