@@ -23,16 +23,15 @@ public:
 	Engine(); 
 	virtual ~Engine(){}
 	virtual bool getInput() = 0;
-	virtual string getCommand();
-	virtual string getOutputDir()			{	return cFactory->getOutputDir();	}
-	virtual string getLogFileName()			{	return cFactory->getLogfileName(); 	}
-	virtual bool getAppend()				{	return cFactory->getAppend();		}
+	virtual string getLogFileName()			{	return mout->getLogFileName();          }
 
 	vector<string> getOptions()		{	return options;		}
 protected:
 	vector<string> options;
 	CommandFactory* cFactory;
 	MothurOut* mout;
+    CurrentFile* current;
+    Utils util;
 };
 
 
@@ -42,7 +41,7 @@ public:
 	BatchEngine(string, string);
 	~BatchEngine();
 	virtual bool getInput();
-	int openedBatch;
+	bool openedBatch;
 private:
 	ifstream inputBatchFile;
 	string getNextCommand(ifstream&);
@@ -56,7 +55,9 @@ public:
 	InteractEngine(string);
 	~InteractEngine();
 	virtual bool getInput();
+    
 private:
+    string getCommand();
 	
 };
 
@@ -66,7 +67,7 @@ public:
 	ScriptEngine(string, string);
 	~ScriptEngine();
 	virtual bool getInput();
-	int openedBatch;
+	bool openedBatch;
 private:
 	string listOfCommands;
 	string getNextCommand(string&);
