@@ -24,7 +24,7 @@ HeatMapSim::HeatMapSim(string dir, string i, int f) : outputDir(dir), inputfile(
 		m = MothurOut::getInstance();
 }
 //**********************************************************************************************************************
-vector<string> HeatMapSim::getPic(vector<SharedRAbundVector*> lookup, vector<Calculator*> calcs) {
+vector<string> HeatMapSim::getPic(vector<SharedRAbundVector*> lookup, vector<Calculator*> calcs, vector<string> groups) {
 	try {
 		EstOutput data;
 		vector<double> sims;
@@ -33,10 +33,10 @@ vector<string> HeatMapSim::getPic(vector<SharedRAbundVector*> lookup, vector<Cal
 		//make file for each calculator selected
 		for (int k = 0; k < calcs.size(); k++) {
 		
-			if (m->control_pressed) { return outputNames; }
+			if (m->getControl_pressed()) { return outputNames; }
 		
-			string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + calcs[k]->getName() + ".heatmap.sim.svg";
-			m->openOutputFile(filenamesvg, outsvg);
+			string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + lookup[0]->getLabel() + "." + calcs[k]->getName() + ".heatmap.sim.svg";
+			util.openOutputFile(filenamesvg, outsvg);
 			outputNames.push_back(filenamesvg);
 			
 			//svg image
@@ -49,8 +49,8 @@ vector<string> HeatMapSim::getPic(vector<SharedRAbundVector*> lookup, vector<Cal
 		
 			//column labels
 			for (int h = 0; h < lookup.size(); h++) {
-				outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(((150 * (h+1)) ) - ((int)lookup[h]->getGroup().length() / 2)) + "\" y=\"50\">" + lookup[h]->getGroup() + "</text>\n"; 
-				outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" y=\"" + toString(((150 * (h+1)) ) - ((int)lookup[h]->getGroup().length() / 2)) + "\" x=\"50\">" + lookup[h]->getGroup() + "</text>\n";
+				outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" x=\"" + toString(((150 * (h+1)) ) - ((int)groups[h].length() / 2)) + "\" y=\"50\">" + groups[h] + "</text>\n";
+				outsvg << "<text fill=\"black\" class=\"seri\" font-size=\"" + toString(fontSize) + "\" y=\"" + toString(((150 * (h+1)) ) - ((int)groups[h].length() / 2)) + "\" x=\"50\">" + groups[h] + "</text>\n";
 			}
 			
 			sims.clear();
@@ -62,7 +62,7 @@ vector<string> HeatMapSim::getPic(vector<SharedRAbundVector*> lookup, vector<Cal
 			for(int i = 0; i < (lookup.size()-1); i++){
 				for(int j = (i+1); j < lookup.size(); j++){
 						
-						if (m->control_pressed) { outsvg.close(); return outputNames; }
+						if (m->getControl_pressed()) { outsvg.close(); return outputNames; }
 						
 						vector<SharedRAbundVector*> subset;
 						subset.push_back(lookup[i]);  subset.push_back(lookup[j]); 
@@ -117,8 +117,8 @@ string HeatMapSim::getPic(vector< vector<double> > dists, vector<string> groups)
 		
 		vector<double> sims;
 		
-		string filenamesvg = outputDir + m->getRootName(m->getSimpleName(inputfile)) + "heatmap.sim.svg";
-		m->openOutputFile(filenamesvg, outsvg);
+		string filenamesvg = outputDir + util.getRootName(util.getSimpleName(inputfile)) + "heatmap.sim.svg";
+		util.openOutputFile(filenamesvg, outsvg);
 			
 		//svg image
 		outsvg << "<svg xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns=\"http://www.w3.org/2000/svg\" width=\"100%\" height=\"100%\" viewBox=\"0 0 " + toString((dists.size() * 150) + 160) + " " + toString((dists.size() * 150) + 160)  + "\">\n";
@@ -142,7 +142,7 @@ string HeatMapSim::getPic(vector< vector<double> > dists, vector<string> groups)
 		for(int i = 0; i < (dists.size()-1); i++){
 			for(int j = (i+1); j < dists.size(); j++){
 			
-				if (m->control_pressed) { outsvg.close(); return filenamesvg; }
+				if (m->getControl_pressed()) { outsvg.close(); return filenamesvg; }
 				
 				float sim = 1.0 - dists[i][j];
 				sims.push_back(sim);
