@@ -9,10 +9,8 @@
  *
  */
 
-
-#include "sharedrabundvector.h"
-#include "datavector.hpp"
 #include "calculator.h"
+#include "utils.hpp"
 
 /***********************************************************************/
 
@@ -22,7 +20,7 @@ class HeatMapSim {
 		HeatMapSim(string, string, int);
 		~HeatMapSim(){};
 	
-		vector<string> getPic(vector<SharedRAbundVector*>, vector<Calculator*>);
+		vector<string> getPic(vector<SharedRAbundVector*>, vector<Calculator*>, vector<string>);
 		string getPic(vector< vector<double> >, vector<string>);
 
 	private:
@@ -32,6 +30,7 @@ class HeatMapSim {
 		int fontSize;
 		ofstream outsvg;
 		MothurOut* m;
+        Utils util;
 			
 };
 
