@@ -37,7 +37,6 @@ double LinearAlgebra::erfcc(double x){
             t*(-0.18628806+t*(0.27886807+t*(-1.13520398+t*(1.48851587+
             t*(-0.82215223+t*0.17087277))))))))); 
         
-        //cout << "in erfcc " << t << '\t' << ans<< endl;
         return (x >= 0.0 ? ans : 2.0 - ans);
     }
 	catch(exception& e) {
@@ -53,8 +52,8 @@ double LinearAlgebra::betai(const double a, const double b, const double x) {
         double result = 0.0;
         
         if (x < 0.0 || x > 1.0) { m->mothurOut("[ERROR]: bad x in betai.\n"); m->setControl_pressed(true); return 0.0; }
-        
-        if (x == 0.0 || x == 1.0)  { bt = 0.0; }
+  
+        if (util.isEqual(x,0.0) || util.isEqual(x,1.0))  { bt = 0.0; }
         else { bt = exp(gammln(a+b)-gammln(a)-gammln(b)+a*log(x)+b*log(1.0-x));  }
         
         if (x < (a+1.0) / (a+b+2.0)) { result = bt*betacf(a,b,x)/a; }
@@ -339,7 +338,7 @@ int LinearAlgebra::tred2(vector<vector<double> >& a, vector<double>& d, vector<d
 				for(int k=0;k<l+1;k++){
 					scale += fabs(a[i][k]);
 				}
-				if(scale == 0.0){
+				if(util.isEqual(scale,0.0)){
 					e[i] = a[i][l];
 				}
 				else{
@@ -387,7 +386,7 @@ int LinearAlgebra::tred2(vector<vector<double> >& a, vector<double>& d, vector<d
 		
 		for(int i=0;i<n;i++){
 			int l = i;
-			if(d[i] != 0.0){
+			if(!util.isEqual(d[i], 0)){
 				for(int j=0;j<l;j++){
 					g = 0.0000;
 					for(int k=0;k<l;k++){
@@ -437,7 +436,7 @@ int LinearAlgebra::qtli(vector<double>& d, vector<double>& e, vector<vector<doub
 			do {
 				for(myM=l;myM<n-1;myM++){
 					dd = fabs(d[myM]) + fabs(d[myM+1]);
-					if(fabs(e[myM])+dd == dd) break;
+					if(util.isEqual(fabs(e[myM])+dd, dd)) break;
 				}
 				if(myM != l){
 					if(iter++ == 3000) cerr << "Too many iterations in qtli\n";
@@ -450,7 +449,7 @@ int LinearAlgebra::qtli(vector<double>& d, vector<double>& e, vector<vector<doub
 						f = s * e[i];
 						b = c * e[i];
 						e[i+1] = (r=pythag(f,g));
-						if(r==0.0){
+						if(util.isEqual(r,0.0)){
 							d[i+1] -= p;
 							e[myM] = 0.0000;
 							break;
@@ -467,7 +466,7 @@ int LinearAlgebra::qtli(vector<double>& d, vector<double>& e, vector<vector<doub
 							z[k][i] = c * z[k][i] - s * f;
 						}
 					}
-					if(r == 0.00 && i >= l) continue;
+					if(util.isEqual(r,0.0) && i >= l) continue;
 					d[l] -= p;
 					e[l] = g;
 					e[myM] = 0.0;
@@ -753,7 +752,7 @@ double LinearAlgebra::calcSpearman(vector< vector<double> >& euclidDists, vector
 			ties.push_back(scores[j]);
 			
 			if (j != (scores.size()-1)) { // you are not the last so you can look ahead
-				if (scores[j].score != scores[j+1].score) { // you are done with ties, rank them and continue
+				if (!util.isEqual(scores[j].score, scores[j+1].score)) { // you are done with ties, rank them and continue
 					
 					for (int k = 0; k < ties.size(); k++) {
 						float thisrank = rankTotal / (float) ties.size();
@@ -832,7 +831,7 @@ double LinearAlgebra::calcKendall(vector< vector<double> >& euclidDists, vector<
 			ties.push_back(scores[j]);
 			
 			if (j != (scores.size()-1)) { // you are not the last so you can look ahead
-				if (scores[j].score != scores[j+1].score) { // you are done with ties, rank them and continue
+				if (!util.isEqual(scores[j].score, scores[j+1].score)) { // you are done with ties, rank them and continue
 					
 					for (int k = 0; k < ties.size(); k++) {
 						float thisrank = rankTotal / (float) ties.size();
@@ -870,7 +869,7 @@ double LinearAlgebra::calcKendall(vector< vector<double> >& euclidDists, vector<
 			ties.push_back(scoresUser[j]);
 			
 			if (j != (scoresUser.size()-1)) { // you are not the last so you can look ahead
-				if (scoresUser[j].score != scoresUser[j+1].score) { // you are done with ties, rank them and continue
+				if (!util.isEqual(scoresUser[j].score, scoresUser[j+1].score)) { // you are done with ties, rank them and continue
 					
 					for (int k = 0; k < ties.size(); k++) {
 						float thisrank = rankTotal / (float) ties.size();
@@ -951,7 +950,7 @@ double LinearAlgebra::calcKendall(vector<double>& x, vector<double>& y, double&
 			ties.push_back(&(xscores[j]));
 				
 			if (j != xscores.size()-1) { // you are not the last so you can look ahead
-				if (xscores[j].score != xscores[j+1].score) { // you are done with ties, rank them and continue
+				if (!util.isEqual(xscores[j].score, xscores[j+1].score)) { // you are done with ties, rank them and continue
 					for (int k = 0; k < ties.size(); k++) {
 						float thisrank = rankTotal / (float) ties.size();
 						(*ties[k]).score = thisrank;
@@ -987,7 +986,7 @@ double LinearAlgebra::calcKendall(vector<double>& x, vector<double>& y, double&
 			yties.push_back(yscores[j]);
 				
 			if (j != yscores.size()-1) { // you are not the last so you can look ahead
-				if (yscores[j].score != yscores[j+1].score) { // you are done with ties, rank them and continue
+				if (!util.isEqual(yscores[j].score, yscores[j+1].score)) { // you are done with ties, rank them and continue
 					for (int k = 0; k < yties.size(); k++) {
 						float thisrank = rankTotal / (float) yties.size();
 						rank[yties[k].name] = thisrank;
@@ -1244,7 +1243,7 @@ double LinearAlgebra::calcKruskalWallis(vector<spearmanRank>& values, double& pV
             ties.push_back(&(values[j]));
             
             if (j != values.size()-1) { // you are not the last so you can look ahead
-                if (values[j].score != values[j+1].score) { // you are done with ties, rank them and continue
+                if (!util.isEqual(values[j].score, values[j+1].score)) { // you are done with ties, rank them and continue
                     if (ties.size() > 1) { TIES.push_back(ties.size()); }
                     for (int k = 0; k < ties.size(); k++) {
                         double thisrank = rankTotal / (double) ties.size();
@@ -1380,7 +1379,7 @@ double LinearAlgebra::calcWilcoxon(vector<double>& x, vector<double>& y, double&
 			ties.push_back(&(ranks[j]));
             
 			if (j != ranks.size()-1) { // you are not the last so you can look ahead
-				if (ranks[j].score != ranks[j+1].score) { // you are done with ties, rank them and continue
+				if (!util.isEqual(ranks[j].score, ranks[j+1].score)) { // you are done with ties, rank them and continue
                     if (ties.size() > 1) { TIES.push_back(ties.size()); }
 					for (int k = 0; k < ties.size(); k++) {
 						float thisrank = rankTotal / (float) ties.size();
@@ -1526,7 +1525,7 @@ double LinearAlgebra::calcSpearman(vector<double>& x, vector<double>& y, double&
 			xties.push_back(xscores[j]);
 			
 			if (j != xscores.size()-1) { // you are not the last so you can look ahead
-				if (xscores[j].score != xscores[j+1].score) { // you are done with ties, rank them and continue
+				if (!util.isEqual(xscores[j].score, xscores[j+1].score)) { // you are done with ties, rank them and continue
 					for (int k = 0; k < xties.size(); k++) {
 						float thisrank = rankTotal / (float) xties.size();
 						rankx[xties[k].name] = thisrank;
@@ -1578,7 +1577,7 @@ double LinearAlgebra::calcSpearman(vector<double>& x, vector<double>& y, double&
 			yties.push_back(yscores[j]);
 			
 			if (j != yscores.size()-1) { // you are not the last so you can look ahead
-				if (yscores[j].score != yscores[j+1].score) { // you are done with ties, rank them and continue
+				if (!util.isEqual(yscores[j].score, yscores[j+1].score)) { // you are done with ties, rank them and continue
 					for (int k = 0; k < yties.size(); k++) {
 						float thisrank = rankTotal / (float) yties.size();
 						rank[yties[k].name] = thisrank;
@@ -1819,7 +1818,7 @@ void LinearAlgebra::ludcmp(vector<vector<double> >& A, vector<int>& index, doubl
                 if (thisValue > big)  { big = thisValue;  }
             }
 
-            if(big==0.0){   m->mothurOut("[WARNING]: " + toString(i) + " produces singular matrix in routine ludcmp\n");   vv[i] = 0.0; }
+            if(util.isEqual(big,(float) 0.0)){   m->mothurOut("[WARNING]: " + toString(i) + " produces singular matrix in routine ludcmp\n");   vv[i] = 0.0; }
             else { vv[i] = 1.0/big;  }
         }
         
@@ -1853,7 +1852,7 @@ void LinearAlgebra::ludcmp(vector<vector<double> >& A, vector<int>& index, doubl
             }
             index[j] = imax;
             
-            if(A[j][j] == 0.0){ A[j][j] = tiny; }
+            if(util.isEqual(A[j][j], 0.0)){ A[j][j] = tiny; }
             
             if(j != n-1){
                 double dum = 1.0/A[j][j];
@@ -1871,13 +1870,13 @@ void LinearAlgebra::ludcmp(vector<vector<double> >& A, vector<int>& index, doubl
 
 void LinearAlgebra::lubksb(vector<vector<double> >& A, vector<int>& index, vector<double>& b){
     try {
-        //if(m->debug){   m->mothurOut("lubksb\n");    }
+        
         double total;
         int n = (int)A.size();
         int ii = 0;
         
         for(int i=0;i<n;i++){
-            //if(m->debug){   m->mothurOut("i loop " + toString(i) + "\n");    }
+            
             if (m->getControl_pressed()) { break; }
             int ip = index[i];
             total = b[ip];
@@ -1885,21 +1884,21 @@ void LinearAlgebra::lubksb(vector<vector<double> >& A, vector<int>& index, vecto
             
             if (ii != 0) {
                 for(int j=ii-1;j<i;j++){
-                    //if(m->debug){   m->mothurOut("j loop " + toString(j) + "\n");    }
+                    
                     total -= A[i][j] * b[j];
                 }
             }
-            else if(total != 0){  ii = i+1;   }
+            else if(!util.isEqual(total, 0)){  ii = i+1;   }
             b[i] = total;
         }
         for(int i=n-1;i>=0;i--){
-            //if(m->debug){   m->mothurOut("i loop " + toString(i) + "\n");    }
+            
             total = b[i];
             for(int j=i+1;j<n;j++){ total -= A[i][j] * b[j];   }
             b[i] = total / A[i][i];
-            //if (A[i][i] == 0) { cout << "ohno!!" << endl; }
+            
         }
-        //if(m->debug){   m->mothurOut("end lubksb\n");    }
+        
     }
 	catch(exception& e) {
 		m->errorOut(e, "LinearAlgebra", "lubksb");
@@ -1910,33 +1909,31 @@ void LinearAlgebra::lubksb(vector<vector<double> >& A, vector<int>& index, vecto
 
 void LinearAlgebra::ludcmp(vector<vector<float> >& A, vector<int>& index, float& d){
     try {
-        //if(m->debug){   m->mothurOut("ludcmp\n");    }
         double tiny = 1e-20;
         
         int n = (int)A.size();
         vector<float> vv(n, 0.0);
-        double temp;
         int imax;
         
         d = 1.0;
         
         for(int i=0;i<n;i++){
-            //if(m->debug){   m->mothurOut("i loop " + toString(i) + "\n");    }
+            
             float big = 0.0;
             for(int j=0;j<n;j++){
                 float thisValue = fabs(A[i][j]);
                 if (thisValue > big)  { big = thisValue;  }
             }
                                                     
-            if(big==0.0){   m->mothurOut("[WARNING]: " + toString(i) + " produces singular matrix in routine ludcmp\n");   vv[i] = 0.0; }
+            if(util.isEqual(big,(float) 0.0)){   m->mothurOut("[WARNING]: " + toString(i) + " produces singular matrix in routine ludcmp\n");   vv[i] = 0.0; }
             else { vv[i] = 1.0/big;  }
         }
         
         for(int j=0;j<n;j++){
             if (m->getControl_pressed()) { break; }
-            //if(m->debug){   m->mothurOut("j loop " + toString(j) + "\n");    }
+            
             for(int i=0;i<j;i++){
-                //if(m->debug){   m->mothurOut("i loop " + toString(i) + "\n");    }
+                
                 float sum = A[i][j];
                 for(int k=0;k<i;k++){   sum -= A[i][k] * A[k][j];   }
                 A[i][j] = sum;
@@ -1944,7 +1941,7 @@ void LinearAlgebra::ludcmp(vector<vector<float> >& A, vector<int>& index, float&
             
             float big = 0.0;
             for(int i=j;i<n;i++){
-                //if(m->debug){   m->mothurOut("j loop " + toString(j) + "\n");    }
+                
                 float sum = A[i][j];
                 for(int k=0;k<j;k++){   sum -= A[i][k] * A[k][j];   }
                 A[i][j] = sum;
@@ -1965,14 +1962,14 @@ void LinearAlgebra::ludcmp(vector<vector<float> >& A, vector<int>& index, float&
             }
             index[j] = imax;
             
-            if(A[j][j] == 0.0){ A[j][j] = tiny; }
+            if(util.isEqual(A[j][j],(float) 0.0)){ A[j][j] = tiny; }
             
             if(j != n-1){
                 float dum = 1.0/A[j][j];
                 for(int i=j+1;i<n;i++){ A[i][j] *= dum; }
             }
         }
-        //if(m->debug){   m->mothurOut("end ludcmp\n");    }
+        
     }
 	catch(exception& e) {
 		m->errorOut(e, "LinearAlgebra", "ludcmp");
@@ -1999,7 +1996,7 @@ void LinearAlgebra::lubksb(vector<vector<float> >& A, vector<int>& index, vector
                     total -= A[i][j] * b[j];
                 }
             }
-            else if(total != 0){  ii = i+1;   }
+            else if(!util.isEqual(total, 0)){  ii = i+1;   }
             b[i] = total;
         }
         for(int i=n-1;i>=0;i--){
@@ -2120,12 +2117,7 @@ vector< vector<double> > LinearAlgebra::lda(vector< vector<double> >& a, vector<
             }
             scaling.push_back(temp);
         }
-        /*
-         cout << "scaling = " << endl;
-         for (int i = 0; i < scaling.size(); i++) {
-         for (int j = 0; j < scaling[i].size(); j++) { cout << scaling[i][j] << '\t'; }
-         cout << endl;
-         }*/
+        
         
         //X <- sqrt(fac) * ((x - group.means[g, ]) %*% scaling)
         vector< vector<double> > X = randCov; //[numOTUS][numSampled]
@@ -2147,22 +2139,11 @@ vector< vector<double> > LinearAlgebra::lda(vector< vector<double> >& a, vector<
         else                        { Xcopy = X;                    }
         linear.svd(Xcopy, d, v); //Xcopy gets the results we want for v below, because R's version is [numSampled][numOTUS]
         
-        /*cout << "Xcopy = " << endl;
-        for (int i = 0; i < Xcopy.size(); i++) {
-            for (int j = 0; j < Xcopy[i].size(); j++) { cout << Xcopy[i][j] << '\t'; }
-            cout << endl;
-        }
-        cout << "v = " << endl;
-        for (int i = 0; i < v.size(); i++) {
-            for (int j = 0; j < v[i].size(); j++) { cout << v[i][j] << '\t'; }
-            cout << endl;
-        }
-         */
         
         int rank = 0;
         set<int> goodColumns;
-        //cout << "d = " << endl;
-        for (int i = 0; i < d.size(); i++) {  if (d[i] > 0.0000000001) { rank++; goodColumns.insert(i); } } //cout << d[i] << endl;
+        
+        for (int i = 0; i < d.size(); i++) {  if (d[i] > 0.0000000001) { rank++; goodColumns.insert(i); } }
         
         if (rank == 0) {
             ignore=true; //m->mothurOut("[ERROR]: rank = 0: variables are numerically const\n"); m->setControl_pressed(true);
@@ -2198,12 +2179,6 @@ vector< vector<double> > LinearAlgebra::lda(vector< vector<double> >& a, vector<
          */
         if (transpose) {
             Xcopy = linear.transpose(v);
-            /*
-            cout << "Xcopy = " << endl;
-            for (int i = 0; i < Xcopy.size(); i++) {
-                for (int j = 0; j < Xcopy[i].size(); j++) { cout << Xcopy[i][j] << '\t'; }
-                cout << endl;
-            }*/
         }
         v.clear(); //store "good" columns - X.s$v[, 1L:rank]
         v.resize(Xcopy.size()); //[numOTUS]["good" columns]
@@ -2220,19 +2195,13 @@ vector< vector<double> > LinearAlgebra::lda(vector< vector<double> >& a, vector<
         
         scaling = linear.matrix_mult(linear.matrix_mult(scaling, v), diagRanks); //([numOTUS][numOTUS]*[numOTUS]["good" columns]) = [numOTUS]["good" columns] then ([numOTUS]["good" columns] * ["good" columns]["good" columns] = scaling = [numOTUS]["good" columns]
         
-        /*cout << "scaling = " << endl;
-        for (int i = 0; i < scaling.size(); i++) {
-            for (int j = 0; j < scaling[i].size(); j++) { cout << scaling[i][j] << '\t'; }
-            cout << endl;
-        }*/
+        
         
         //Note: linear.matrix_mult [1][numGroups] * [numGroups][numOTUs] - columns in first must match rows in second, returns matrix[1][numOTUs]
         vector< vector<double> > prior; prior.push_back(proportions);
         vector< vector<double> >  xbar = linear.matrix_mult(prior, means);
         vector<double> xBar = xbar[0]; //length numOTUs
         
-        /*cout << "xbar" << endl;
-        for (int j = 0; j < numOtus; j++) {  cout << xBar[j] <<'\t'; }cout <<  endl;*/
         //fac <- 1/(ng - 1)
         fac = 1 / (double) (numGroups-1);
         //scale(group.means, center = xbar, scale = FALSE) %*% scaling
@@ -2253,13 +2222,7 @@ vector< vector<double> > LinearAlgebra::lda(vector< vector<double> >& a, vector<
         for (int i = 0; i < X.size(); i++) {
             for (int j = 0; j < X[i].size(); j++) {  X[i][j] *= temp[j];  }
         }
-        /*
-        cout << "X = " << endl;
-        for (int i = 0; i < X.size(); i++) {
-            for (int j = 0; j < X[i].size(); j++) { cout << X[i][j] << '\t'; }
-            cout << endl;
-        }
-        */
+        
         
         d.clear(); v.clear();
         //we want to transpose so results are in Xcopy, but if that makes rows > columns then we don't since svd requires rows < cols.
@@ -2267,20 +2230,7 @@ vector< vector<double> > LinearAlgebra::lda(vector< vector<double> >& a, vector<
         if (X.size() > X[0].size()) {   Xcopy = X;  transpose=true;     }
         else                        {   Xcopy = linear.transpose(X);    }
         linear.svd(Xcopy, d, v); //Xcopy gets the results we want for v below
-        /*cout << "Xcopy = " << endl;
-        for (int i = 0; i < Xcopy.size(); i++) {
-            for (int j = 0; j < Xcopy[i].size(); j++) { cout << Xcopy[i][j] << '\t'; }
-            cout << endl;
-        }
         
-        cout << "v = " << endl;
-        for (int i = 0; i < v.size(); i++) {
-            for (int j = 0; j < v[i].size(); j++) { cout << v[i][j] << '\t'; }
-            cout << endl;
-        }
-        
-        cout << "d = " << endl;
-        for (int i = 0; i < d.size(); i++) { cout << d[i] << endl; }*/
         
         //rank <- sum(X.s$d > tol * X.s$d[1L])
         //X.s$d[1L] = larger value in d vector
@@ -2304,11 +2254,7 @@ vector< vector<double> > LinearAlgebra::lda(vector< vector<double> >& a, vector<
         
         scaling = linear.matrix_mult(scaling, v); //[numOTUS]["good" columns] * ["good"columns][new "good" columns]
         
-        /*cout << "scaling = " << endl;
-        for (int i = 0; i < scaling.size(); i++) {
-            for (int j = 0; j < scaling[i].size(); j++) { cout << scaling[i][j] << '\t'; }
-            cout << endl;
-        }*/
+        
         ignore=false;
         return scaling;
     }
@@ -2495,12 +2441,12 @@ int LinearAlgebra::svd(vector< vector<double> >& a, vector<double>& w, vector< v
                 for (l = k; l >= 0; l--)
                 {                     /* test for splitting */
                     nm = l - 1;
-                    if (fabs(rv1[l]) + anorm == anorm)
+                    if (util.isEqual((fabs(rv1[l]) + anorm), anorm))
                     {
                         flag = 0;
                         break;
                     }
-                    if (fabs((double)w[nm]) + anorm == anorm)
+                    if (util.isEqual((fabs((double)w[nm]) + anorm), anorm))
                         break;
                 }
                 if (flag)
@@ -2510,7 +2456,7 @@ int LinearAlgebra::svd(vector< vector<double> >& a, vector<double>& w, vector< v
                     for (i = l; i <= k; i++)
                     {
                         f = s * rv1[i];
-                        if (fabs(f) + anorm != anorm)
+                        if (!util.isEqual((fabs(f) + anorm), anorm))
                         {
                             g = (double)w[i];
                             h = pythag(f, g);
