@@ -13,6 +13,7 @@
 
 void RareDisplay::init(string label){
 	try {
+        lock_guard<std::mutex> guard(mutex);
 		this->label = label;
 	}
 	catch(exception& e) {
@@ -25,6 +26,8 @@ void RareDisplay::init(string label){
 
 void RareDisplay::update(SAbundVector* rank){
 	try {
+        lock_guard<std::mutex> guard(mutex);
+        
 		int newNSeqs = rank->getNumSeqs();
 		vector<double> data = estimate->getValues(rank);
 
@@ -46,6 +49,8 @@ void RareDisplay::update(SAbundVector* rank){
 /***********************************************************************/
 void RareDisplay::update(vector<SharedRAbundVector*> shared, int numSeqs, int numGroupComb, vector<string> g) {
 	try {
+        lock_guard<std::mutex> guard(mutex);
+        
 		vector<double> data = estimate->getValues(shared);
         Groups = g;
 		
@@ -68,6 +73,7 @@ void RareDisplay::update(vector<SharedRAbundVector*> shared, int numSeqs, int nu
 
 void RareDisplay::reset(){
 	try {
+        lock_guard<std::mutex> guard(mutex);
 		nIters++;
 	}
 	catch(exception& e) {
@@ -77,10 +83,10 @@ void RareDisplay::reset(){
 }
 
 /***********************************************************************/
-
+//assumes only one thread will run close
 void RareDisplay::close(){
 	try {
-		output->initFile(label);
+		output->setLabelName(label);
 	
 		for (map<int, vector<double> >::iterator it = results.begin(); it != results.end(); it++) {
 		
@@ -93,11 +99,8 @@ void RareDisplay::close(){
 			data[0] = meanResults;
 			data[1] = (it->second)[(int)(0.025*(nIters-1))];
 			data[2] = (it->second)[(int)(0.975*(nIters-1))];
-            //cout << nIters << '\t' << (int)(0.025*(nIters-1)) << '\t' << (int)(0.975*(nIters-1)) << endl;
-            
-            //cout << it->first << '\t' << data[1] << '\t' << data[2] << endl;
 		
-			output->output(it->first, data);
+			output->updateOutput(it->first, data);
 		}
 		
 		nIters = 1;
@@ -111,70 +114,3 @@ void RareDisplay::close(){
 	}
 }
 /***********************************************************************/
-
-void RareDisplay::inputTempFiles(string filename){
-	try {
-		ifstream in;
-		util.openInputFile(filename, in);
-		
-		int thisIters, size;
-		in >> thisIters >> size; util.gobble(in);
-        nIters += thisIters;
-		
-		for (int i = 0; i < size; i++) {
-			int tempCount;
-            in >> tempCount; util.gobble(in);
-            map<int, vector<double> >::iterator it = results.find(tempCount);
-            if (it != results.end()) {
-                for (int j = 0; j < thisIters; j++) {
-                    double value;
-                    in >> value; util.gobble(in);
-                    (it->second).push_back(value);
-                }
-            }else {
-                vector<double> tempValues;
-                for (int j = 0; j < thisIters; j++) {
-                    double value;
-                    in >> value; util.gobble(in);
-                    tempValues.push_back(value);
-                }
-                results[tempCount] = tempValues;
-            }
-		}
-		
-		in.close();
-	}
-	catch(exception& e) {
-		m->errorOut(e, "RareDisplay", "inputTempFiles");
-		exit(1);
-	}
-}
-
-/***********************************************************************/
-
-void RareDisplay::outputTempFiles(string filename){
-	try {
-		ofstream out;
-		util.openOutputFile(filename, out);
-		
-		out << nIters-1 << '\t' << results.size() << endl;
-		
-		for (map<int, vector<double> >::iterator it = results.begin(); it != results.end(); it++) {
-            out << it->first;
-            for(int i = 0; i < (it->second).size(); i++) {
-                out << '\t' << (it->second)[i];
-            }
-            out << endl;
-		}
-		
-		out.close();
-	}
-	catch(exception& e) {
-		m->errorOut(e, "RareDisplay", "outputTempFiles");
-		exit(1);
-	}
-}
-
-
-/***********************************************************************/
-
