@@ -8,7 +8,7 @@
  */
 
 #include "readblast.h"
-#include "progress.hpp"
+
 
 //********************************************************************************************************************
 //sorts lowest to highest
@@ -59,8 +59,6 @@ int ReadBlast::read(NameAssignment* nameMap) {
 		
 		if (m->getControl_pressed()) { fileHandle.close(); delete matrix; return 0; }
 		
-		Progress* reading = new Progress("Reading blast:     ", nseqs * nseqs);
-		
 		//this is used to quickly find if we already have a distance for this combo
 		vector< map<int,float> > dists;  dists.resize(nseqs);  //dists[0][1] = distance from seq0 to seq1
 		map<int, float> thisRowsBlastScores;
@@ -88,7 +86,7 @@ int ReadBlast::read(NameAssignment* nameMap) {
 				thisoverlap = 1.0 - (percentId * (lengthThisSeq - startQuery) / endRef / 100.0 - penalty);
 				
 				//if there is a valid overlap, add it
-				if ((startRef <= length) && ((endQuery+length) >= lengthThisSeq) && (thisoverlap < cutoff)) {
+				if ((startRef <= length) && ((endQuery+length) >= lengthThisSeq) && (thisoverlap <= cutoff)) {
                     seqDist overlapValue(itA->second, itB->second, thisoverlap);
                     overlap.push_back(overlapValue);
 				}
@@ -99,11 +97,11 @@ int ReadBlast::read(NameAssignment* nameMap) {
 		//read file
 		while(!fileHandle.eof()){  
 		
-			if (m->getControl_pressed()) { fileHandle.close(); delete matrix; delete reading; return 0; }
+			if (m->getControl_pressed()) { fileHandle.close(); delete matrix;  return 0; }
 			
 			//read in line from file
 			fileHandle >> firstName >> secondName >> percentId >> numBases >> mismatch >> gap >> startQuery >> endQuery >> startRef >> endRef >> eScore >> score;
-			//cout << firstName << '\t' << secondName << '\t' << percentId << '\t' << numBases << '\t' << mismatch << '\t' << gap << '\t' << startQuery << '\t' << endQuery << '\t' << startRef << '\t' << endRef << '\t' << eScore << '\t' << score << endl;	
+			
 			util.gobble(fileHandle);
 			
 			string temp = firstName + secondName; //to check if this file has repeat lines, ie. is this a blast instead of a blscreen file
@@ -113,10 +111,9 @@ int ReadBlast::read(NameAssignment* nameMap) {
 				repeatName = temp; 
 				
 				if (currentRow == firstName) {
-					//cout << "first = " << firstName << " second = " << secondName << endl;	
+						
 					if (firstName == secondName) { 
 						refScore = score;  
-						reading->update((count + nseqs));  
 						count++; 
 					}else{
 						//convert name to number
@@ -132,9 +129,8 @@ int ReadBlast::read(NameAssignment* nameMap) {
 						thisoverlap = 1.0 - (percentId * (lengthThisSeq - startQuery) / endRef / 100.0 - penalty);
 						
 						//if there is a valid overlap, add it
-						if ((startRef <= length) && ((endQuery+length) >= lengthThisSeq) && (thisoverlap < cutoff)) {
+						if ((startRef <= length) && ((endQuery+length) >= lengthThisSeq) && (thisoverlap <= cutoff)) {
                             seqDist overlapValue(itA->second, itB->second, thisoverlap);
-                            //cout << "overlap = " << itA->second << '\t' << itB->second << '\t' << thisoverlap << endl;
                             overlap.push_back(overlapValue);
 						}
 					} //end else
@@ -158,7 +154,7 @@ int ReadBlast::read(NameAssignment* nameMap) {
 							else{	distance = min(itDist->second, distance);  }
 
 							//is this distance below cutoff
-							if (distance < cutoff) {
+							if (distance <= cutoff) {
                                 if (itA->second < it->first) {
                                     PDistCell value(it->first, distance);
                                     matrix->addCell(itA->second, value);
@@ -195,7 +191,7 @@ int ReadBlast::read(NameAssignment* nameMap) {
 						thisoverlap = 1.0 - (percentId * (lengthThisSeq - startQuery) / endRef / 100.0 - penalty);
 						
 						//if there is a valid overlap, add it
-						if ((startRef <= length) && ((endQuery+length) >= lengthThisSeq) && (thisoverlap < cutoff)) {
+						if ((startRef <= length) && ((endQuery+length) >= lengthThisSeq) && (thisoverlap <= cutoff)) {
                             seqDist overlapValue(itA->second, itB->second, thisoverlap);
                             overlap.push_back(overlapValue);
 						}
@@ -222,7 +218,7 @@ int ReadBlast::read(NameAssignment* nameMap) {
 				else{	distance = min(itDist->second, distance);  }
 				
 				//is this distance below cutoff
-				if (distance < cutoff) {
+				if (distance <= cutoff) {
                     if (itA->second < it->first) {
                         PDistCell value(it->first, distance);
                         matrix->addCell(itA->second, value);
@@ -241,14 +237,14 @@ int ReadBlast::read(NameAssignment* nameMap) {
 		thisRowsBlastScores.clear();
 		dists.clear();
 		
-		if (m->getControl_pressed()) {  fileHandle.close(); delete matrix; delete reading; return 0; }
+		if (m->getControl_pressed()) {  fileHandle.close(); delete matrix;  return 0; }
 		
         sort(overlap.begin(), overlap.end(), compareOverlap);
  
-		if (m->getControl_pressed()) {  fileHandle.close(); delete matrix; delete reading; return 0; }
+		if (m->getControl_pressed()) {  fileHandle.close(); delete matrix;  return 0; }
+		
+		
 		
-		reading->finish();
-		delete reading;
 		fileHandle.close();
 		
 		return 0;
