@@ -27,8 +27,7 @@ private:
     MothurOut* m;
 	vector<Tree*> trees;
     CountTable* ct;
-    //map<string, string> nameMap; //dupName -> uniqueName
-   // map<string, string> names;
+    vector<string> Treenames;
     
     string treefile, groupfile, namefile, countfile;
     
