@@ -34,10 +34,10 @@ RefChimeraTest::RefChimeraTest(vector<Sequence>& refs, bool aligned) : aligned(a
 }
 //***************************************************************************************************************
 
-int RefChimeraTest::printHeader(ofstream& chimeraReportFile){
+string RefChimeraTest::getHeader(){
 	try {
-		chimeraReportFile << "queryName\tbestRef\tbestSequenceMismatch\tleftParentChi,rightParentChi\tbreakPointChi\tminMismatchToChimera\tdistToBestMera\tnumParents" << endl;
-		return 0; 
+		return ("queryName\tbestRef\tbestSequenceMismatch\tleftParentChi,rightParentChi\tbreakPointChi\tminMismatchToChimera\tdistToBestMera\tnumParents\n");
+		
 	}catch(exception& e) {
 		m->errorOut(e, "RefChimeraTest", "printHeader");
 		exit(1);
@@ -46,15 +46,15 @@ int RefChimeraTest::printHeader(ofstream& chimeraReportFile){
 
 //***************************************************************************************************************
 
-int RefChimeraTest::analyzeQuery(string queryName, string querySeq, ofstream& chimeraReportFile){
+int RefChimeraTest::analyzeQuery(string queryName, string querySeq, string& output){
 
     int numParents = -1;
     
     if(aligned){
-        numParents = analyzeAlignedQuery(queryName, querySeq, chimeraReportFile);
+        numParents = analyzeAlignedQuery(queryName, querySeq, output);
     }
     else{
-        numParents = analyzeUnalignedQuery(queryName, querySeq, chimeraReportFile);
+        numParents = analyzeUnalignedQuery(queryName, querySeq, output);
     }
     
     return numParents;
@@ -63,7 +63,7 @@ int RefChimeraTest::analyzeQuery(string queryName, string querySeq, ofstream& ch
  
 //***************************************************************************************************************
 
-int RefChimeraTest::analyzeAlignedQuery(string queryName, string querySeq, ofstream& chimeraReportFile){
+int RefChimeraTest::analyzeAlignedQuery(string queryName, string querySeq, string& output){
 	
     vector<vector<int> > left; left.resize(numRefSeqs);
     vector<vector<int> > right; right.resize(numRefSeqs);
@@ -75,7 +75,7 @@ int RefChimeraTest::analyzeAlignedQuery(string queryName, string querySeq, ofstr
         right[i].assign(alignLength, 0);
 	}
 	
-    int bestMatchIndex;
+    int bestMatchIndex = 0;
 	int bestSequenceMismatch = getAlignedMismatches(querySeq, left, right, bestMatchIndex);
 	
 	int leftParentBi, rightParentBi, breakPointBi;
@@ -98,10 +98,10 @@ int RefChimeraTest::analyzeAlignedQuery(string queryName, string querySeq, ofstr
     
 	double distToChimera = calcDistToChimera(bestQueryAlignment, bestRefAlignment);
 	
-	chimeraReportFile << queryName << '\t' << referenceNames[bestMatchIndex] << '\t' << bestSequenceMismatch << '\t';
-	chimeraReportFile << referenceNames[leftParentBi] << ',' << referenceNames[rightParentBi] << '\t' << breakPointBi << '\t';
-	chimeraReportFile << minMismatchToChimera << '\t';
-    chimeraReportFile << '\t' << distToChimera << '\t' << nMera << endl;
+	output = queryName + "\t" + referenceNames[bestMatchIndex] + "\t" + toString(bestSequenceMismatch) + "\t";
+	output += referenceNames[leftParentBi] + ',' + referenceNames[rightParentBi] + "\t" + toString(breakPointBi) + "\t";
+	output += toString(minMismatchToChimera) + "\t";
+    output += toString(distToChimera) + "\t" + toString(nMera) +"\n";
     
     bestMatch = bestMatchIndex;
 		
@@ -110,7 +110,7 @@ int RefChimeraTest::analyzeAlignedQuery(string queryName, string querySeq, ofstr
 
 //***************************************************************************************************************
 
-int RefChimeraTest::analyzeUnalignedQuery(string queryName, string querySeq, ofstream& chimeraReportFile){
+int RefChimeraTest::analyzeUnalignedQuery(string queryName, string querySeq, string& output){
 	
     int nMera = 0;
     
@@ -203,7 +203,7 @@ int RefChimeraTest::analyzeUnalignedQuery(string queryName, string querySeq, ofs
             
             for(int i=0;i<=breakLeft;i++){
                 
-                if (m->control_pressed) { return 0; }
+                if (m->getControl_pressed()) { return 0; }
                 
                 if(left[i] != '-' && left[i] != '.'){
                     reference += left[i];
@@ -213,7 +213,7 @@ int RefChimeraTest::analyzeUnalignedQuery(string queryName, string querySeq, ofs
             
             for(int i=breakRight;i<right.length();i++){
                 
-                if (m->control_pressed) { return 0; }
+                if (m->getControl_pressed()) { return 0; }
                 
                 if(right[i] != '-' && right[i] != '.'){
                     reference += right[i];
@@ -225,23 +225,22 @@ int RefChimeraTest::analyzeUnalignedQuery(string queryName, string querySeq, ofs
             nMera = 1;
             reference = referenceSeqs[bestRefIndex];
         }
-
+        
         double alignLength;
         double finalDiffs = alignQueryToReferences(querySeq, reference, bestQueryAlignment, bestRefAlignment, alignLength);
         double finalDistance = finalDiffs / alignLength;
 
-        chimeraReportFile << queryName << '\t' << referenceNames[bestRefIndex] << '\t' << bestRefDiffs << '\t';
-        chimeraReportFile << referenceNames[leftParent] << ',' << referenceNames[rightParent] << '\t' << breakPoint << '\t';
-        chimeraReportFile << bestChimeraMismatches << '\t';
-        chimeraReportFile << '\t' << finalDistance << '\t' << nMera << endl;
+        output = queryName + "\t" +  referenceNames[bestRefIndex] + "\t" + toString(bestRefDiffs) + "\t";
+        output += referenceNames[leftParent] + ',' + referenceNames[rightParent] + "\t" + toString(breakPoint) + "\t";
+        output += toString(bestChimeraMismatches) + "\t";
+        output += toString(finalDistance) + "\t" + toString(nMera) +"\n";
     }
     else{
         bestQueryAlignment = queryAlign[bestRefIndex];
         bestRefAlignment = refAlign[bestRefIndex];
         nMera = 1;
         
-        chimeraReportFile << queryName << '\t' << referenceNames[bestRefIndex] << '\t' << bestRefDiffs << '\t';
-        chimeraReportFile << "NA\tNA\tNA\tNA\t1" << endl;
+        output = queryName + "\t" + referenceNames[bestRefIndex] + "\t" + toString(bestRefDiffs) + "\tNA\tNA\tNA\tNA\t1\n";
     } 
     
     bestMatch = bestRefIndex;
@@ -265,26 +264,26 @@ double RefChimeraTest::alignQueryToReferences(string query, string reference, st
         vector<vector<char> > alignMoves; alignMoves.resize(queryLength + 1);
 		
 		for(int i=0;i<=queryLength;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			alignMatrix[i].resize(refLength + 1, 0);
 			alignMoves[i].resize(refLength + 1, 'x');
 		}
 		
 		for(int i=0;i<=queryLength;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			alignMatrix[i][0] = 0;//GAP * i;
 			alignMoves[i][0] = 'u';
 		}
 		
 		for(int i=0;i<=refLength;i++){
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			alignMatrix[0][i] = 0;//GAP * i;
 			alignMoves[0][i] = 'l';
 		}
 		        
 		for(int i=1;i<=queryLength;i++){
 			
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			for(int j=1;j<=refLength;j++){
 				
@@ -373,7 +372,7 @@ double RefChimeraTest::alignQueryToReferences(string query, string reference, st
 
 		while(i > 0 && j > 0){
 			
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			if(alignMoves[i][j] == 'd'){
 				qAlign = query[i-1] + qAlign;
@@ -429,7 +428,7 @@ int RefChimeraTest::getUnalignedDiffs(string qAlign, string rAlign, vector<int>&
 		int lCount = 0;
 		for(int l=0;l<alignLength;l++){
 			
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			if(qAlign[l] == '-'){
 				lDiffs++;		
@@ -453,7 +452,7 @@ int RefChimeraTest::getUnalignedDiffs(string qAlign, string rAlign, vector<int>&
 		int rCount = 0;
 		for(int l=alignLength-1;l>=0;l--){
 			
-			if (m->control_pressed) { return 0; }
+			if (m->getControl_pressed()) { return 0; }
 			
 			if(qAlign[l] == '-'){
 				rDiffs++;		
