@@ -74,7 +74,7 @@ vector<string> Venn::getPic(SAbundVector* sabund, vector<Calculator*> vCalcs) {
 	}
 }
 //**********************************************************************************************************************
-vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculator*> vCalcs) {
+vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculator*> vCalcs, vector<string> thisOtuLabels) {
 	try {
 
 		vector<SharedRAbundVector*> subset;
@@ -156,7 +156,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 				
 				//get estimates for sharedAB
                 vector<string> labels;
-				vector<double> shared = vCalcs[i]->getValues(subset, labels);
+				vector<double> shared = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 				
 				//in essence you want to run it like a single 
 				if (vCalcs[i]->getName() == "sharedsobs") {
@@ -478,7 +478,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 					subset.clear();
 					subset.push_back(lookup[0]); subset.push_back(lookup[1]);
                     vector<string> labels;
-					vector<double> sharedab =  vCalcs[i]->getValues(subset, labels);
+					vector<double> sharedab =  vCalcs[i]->getValues(subset, labels, thisOtuLabels);
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[1]->getGroup() << '\t' << labels.size() << '\t';
                         for (int k = 0; k < labels.size()-1; k++) {
@@ -490,7 +490,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 					
 					subset.clear(); 
 					subset.push_back(lookup[0]); subset.push_back(lookup[2]);
-					vector<double> sharedac =  vCalcs[i]->getValues(subset, labels);
+					vector<double> sharedac =  vCalcs[i]->getValues(subset, labels, thisOtuLabels);
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[2]->getGroup() << '\t'<< labels.size() << '\t';
                         for (int k = 0; k < labels.size()-1; k++) {
@@ -502,7 +502,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 					
 					subset.clear(); 
 					subset.push_back(lookup[1]); subset.push_back(lookup[2]);
-					vector<double> sharedbc =  vCalcs[i]->getValues(subset, labels);
+					vector<double> sharedbc =  vCalcs[i]->getValues(subset, labels, thisOtuLabels);
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[1]->getGroup() + "-" + lookup[2]->getGroup() << '\t'<< labels.size() << '\t';
                         for (int k = 0; k < labels.size()-1; k++) {
@@ -515,7 +515,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 					
 					subset.clear(); 
 					subset.push_back(lookup[0]); subset.push_back(lookup[1]); subset.push_back(lookup[2]);
-					vector<double> sharedabc =  vCalcs[i]->getValues(subset, labels);
+					vector<double> sharedabc =  vCalcs[i]->getValues(subset, labels, thisOtuLabels);
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[1]->getGroup() + "-" + lookup[2]->getGroup() << '\t'<< labels.size() << '\t';
                         for (int k = 0; k < labels.size()-1; k++) {
@@ -640,20 +640,19 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 					//get estimates for numA
 					data = singleCalc->getValues(sabundA);
 					numA = data[0];
-	//cout << "num a = " << numA << endl;	
+		
  			
 					//get estimates for numB
 					data = singleCalc->getValues(sabundB);
 					numB = data[0];
- 	//cout << "num b = " << numB << endl;				
+ 					
 					//get estimates for numC
 					data = singleCalc->getValues(sabundC);
 					numC = data[0];
-	//cout << "num c = " << numC << endl;				
+					
 					//get estimates for numD
 					data = singleCalc->getValues(sabundD);
 					numD = data[0];
-//cout << "num d = " << numD << endl;	
                     
                     ofstream outShared;
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs")) {
@@ -671,7 +670,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 					subset.clear();
                     vector<string> labels;
 					subset.push_back(lookup[0]); subset.push_back(lookup[1]);
-					data = vCalcs[i]->getValues(subset, labels);
+					data = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 					sharedAB = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[1]->getGroup() << '\t'<< labels.size() << '\t';
@@ -681,10 +680,10 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         if (labels.size() != 0) { outShared << labels[labels.size()-1]; }
                         outShared << endl;
                     }
-	//cout << "num ab = " << sharedAB << endl;			
+			
 					subset.clear();
 					subset.push_back(lookup[0]); subset.push_back(lookup[2]);
-					data = vCalcs[i]->getValues(subset, labels);
+					data = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 					sharedAC = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[2]->getGroup() << '\t'<< labels.size() << '\t';
@@ -694,10 +693,10 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         if (labels.size() != 0) { outShared << labels[labels.size()-1]; }
                         outShared << endl;
                     }
-	//cout << "num ac = " << sharedAC << endl;				
+				
 					subset.clear();
 					subset.push_back(lookup[0]); subset.push_back(lookup[3]);
-					data = vCalcs[i]->getValues(subset, labels);
+					data = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 					sharedAD = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[3]->getGroup() << '\t'<< labels.size() << '\t';
@@ -707,10 +706,10 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         if (labels.size() != 0) { outShared << labels[labels.size()-1]; }
                         outShared << endl;
                     }
-	//cout << "num ad = " << sharedAD << endl;			
+			
 					subset.clear();
 					subset.push_back(lookup[1]); subset.push_back(lookup[2]);
-					data = vCalcs[i]->getValues(subset, labels);
+					data = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 					sharedBC = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[1]->getGroup() + "-" + lookup[2]->getGroup() << '\t'<< labels.size() << '\t';
@@ -720,10 +719,10 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         if (labels.size() != 0) { outShared << labels[labels.size()-1]; }
                         outShared << endl;
                     }
-	//cout << "num bc = " << sharedBC << endl;				
+					
 					subset.clear();
 					subset.push_back(lookup[1]); subset.push_back(lookup[3]);
-					data = vCalcs[i]->getValues(subset, labels);
+					data = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 					sharedBD = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[1]->getGroup() + "-" + lookup[3]->getGroup() << '\t'<< labels.size() << '\t';
@@ -733,10 +732,10 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         if (labels.size() != 0) { outShared << labels[labels.size()-1]; }
                         outShared << endl;
                     }
-		//cout << "num bd = " << sharedBD << endl;						
+							
 					subset.clear();
 					subset.push_back(lookup[2]); subset.push_back(lookup[3]);
-					data = vCalcs[i]->getValues(subset, labels);
+					data = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 					sharedCD = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[2]->getGroup() + "-" + lookup[3]->getGroup() << '\t'<< labels.size() << '\t';
@@ -747,11 +746,11 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         outShared << endl;
                     }
 						
-	//cout << "num cd = " << sharedCD << endl;				
+				
 					//get estimates for combos of 3
 					subset.clear();
 					subset.push_back(lookup[0]); subset.push_back(lookup[1]); subset.push_back(lookup[2]);
-					data = vCalcs[i]->getValues(subset, labels);
+					data = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 					sharedABC = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[1]->getGroup()+ "-" + lookup[2]->getGroup()<< '\t'<< labels.size() << '\t';
@@ -761,10 +760,10 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         if (labels.size() != 0) { outShared << labels[labels.size()-1]; }
                         outShared << endl;
                     }
-		//cout << "num abc = " << sharedABC << endl;					
+						
 					subset.clear();
 					subset.push_back(lookup[0]); subset.push_back(lookup[2]); subset.push_back(lookup[3]);
-					data = vCalcs[i]->getValues(subset, labels);
+					data = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 					sharedACD = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[2]->getGroup()+ "-" + lookup[3]->getGroup()<< '\t'<< labels.size() << '\t';
@@ -774,10 +773,10 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         if (labels.size() != 0) { outShared << labels[labels.size()-1]; }
                         outShared << endl;
                     }
-			//cout << "num acd = " << sharedACD << endl;	
+				
 					subset.clear();
 					subset.push_back(lookup[1]); subset.push_back(lookup[2]); subset.push_back(lookup[3]);
-					data = vCalcs[i]->getValues(subset,labels);
+					data = vCalcs[i]->getValues(subset,labels, thisOtuLabels);
 					sharedBCD = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[1]->getGroup() + "-" + lookup[2]->getGroup()+ "-" + lookup[3]->getGroup()<< '\t'<< labels.size() << '\t';
@@ -787,10 +786,10 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         outShared << labels[labels.size()-1]; 
                         outShared << endl;
                     }
-		//cout << "num bcd = " << sharedBCD << endl;		
+				
 					subset.clear();
 					subset.push_back(lookup[0]); subset.push_back(lookup[1]); subset.push_back(lookup[3]);
-					data = vCalcs[i]->getValues(subset, labels);
+					data = vCalcs[i]->getValues(subset, labels, thisOtuLabels);
 					sharedABD = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[1]->getGroup()+ "-" + lookup[3]->getGroup()<< '\t'<< labels.size() << '\t';
@@ -800,9 +799,9 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         outShared << labels[labels.size()-1]; 
                         outShared << endl;
                     }
-//cout << "num abd = " << sharedABD << endl;
+
 					//get estimate for all four
-					data = vCalcs[i]->getValues(lookup, labels);
+					data = vCalcs[i]->getValues(lookup, labels, thisOtuLabels);
 					sharedABCD = data[0];
                     if (sharedOtus && (vCalcs[i]->getName() == "sharedsobs") &&  (labels.size() != 0)) {
                         outShared << lookup[0]->getGroup() + "-" + lookup[1]->getGroup() + "-" + lookup[2]->getGroup()+ "-" + lookup[3]->getGroup()<< '\t'<< labels.size() << '\t';
@@ -813,7 +812,7 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
                         outShared << endl;
                         outShared.close();
                     }
-		//cout << "num abcd = " << sharedABCD << endl << endl;	
+		
 					int sharedVal, sharedABCVal, sharedABDVal, sharedACDVal, sharedBCDVal, sharedABVal, sharedACVal, sharedADVal, sharedBCVal, sharedBDVal, sharedCDVal, numSeqsA, numSeqsB, numSeqsC, numSeqsD;
 												
 					if (nseqs) {
@@ -923,29 +922,26 @@ vector<string> Venn::getPic(vector<SharedRAbundVector*> lookup, vector<Calculato
 									
 					//make adjustments
 					sharedABC = sharedABC - sharedABCD;
-			//cout << "num abc = " << sharedABC << endl;		
+				
 					sharedABD = sharedABD - sharedABCD;
-				//cout << "num abd = " << sharedABD << endl;
+				
 					sharedACD = sharedACD - sharedABCD;
-				//cout << "num acd = " << sharedACD << endl;
+				
 					sharedBCD = sharedBCD - sharedABCD;
-				//cout << "num bcd = " << sharedBCD << endl;
+				
 					
-					sharedAB = sharedAB - sharedABC - sharedABCD - sharedABD;  //cout << "num ab = " << sharedAB << endl;
-					sharedAC = sharedAC - sharedABC - sharedABCD - sharedACD;  //cout << "num ac = " << sharedAC << endl;
-					sharedAD = sharedAD - sharedABD - sharedABCD - sharedACD;  //cout << "num ad = " << sharedAD << endl;				
-					sharedBC = sharedBC - sharedABC - sharedABCD - sharedBCD;  //cout << "num bc = " << sharedBC << endl;
-					sharedBD = sharedBD - sharedABD - sharedABCD - sharedBCD; // cout << "num bd = " << sharedBD << endl; 
-					sharedCD = sharedCD - sharedACD - sharedABCD - sharedBCD;  //cout << "num cd = " << sharedCD << endl;
+					sharedAB = sharedAB - sharedABC - sharedABCD - sharedABD;
+					sharedAC = sharedAC - sharedABC - sharedABCD - sharedACD;
+					sharedAD = sharedAD - sharedABD - sharedABCD - sharedACD;
+					sharedBC = sharedBC - sharedABC - sharedABCD - sharedBCD;
+					sharedBD = sharedBD - sharedABD - sharedABCD - sharedBCD;
+					sharedCD = sharedCD - sharedACD - sharedABCD - sharedBCD;
 					
 					numA = numA - sharedAB - sharedAC - sharedAD - sharedABCD - sharedABC - sharedACD - sharedABD;
-			//cout << "num a = " << numA << endl;		
 					numB = numB - sharedAB - sharedBC - sharedBD - sharedABCD - sharedABC - sharedABD - sharedBCD;
-			//cout << "num b = " << numB << endl;		
 					numC = numC - sharedAC - sharedBC - sharedCD - sharedABCD - sharedABC - sharedACD - sharedBCD;
-			//cout << "num c = " << numC << endl;		
 					numD = numD - sharedAD - sharedBD - sharedCD - sharedABCD - sharedBCD - sharedACD - sharedABD;
-			//cout << "num d = " << numD << endl;		
+				
 					
 					//draw circles
 					outsvg << "<ellipse fill=\"red\" stroke=\"black\" opacity=\".35\" transform=\"rotate(-45 " +  toString(int(0.51 * width)) +  " " +  toString(int(0.27 * height)) +  ") \" cx=\"" +  toString(int(0.51 * width)) +  "\" cy=\"" +  toString(int(0.27 * height)) +  "\" rx=\"" +  toString(int(0.29 * width)) +  "\" ry=\"" +  toString(int(0.14 * height)) +  "\"/>\n "; 
